# -*- coding: utf-8 -*-
# **********************************************************************
#
# Copyright (c) 2003-2017 ZeroC, Inc. All rights reserved.
#
# This copy of Ice is licensed to you under the terms described in the
# ICE_LICENSE file included in this distribution.
#
# **********************************************************************
#
# Ice version 3.6.4
#
# <auto-generated>
#
# Generated from file `Project.ice'
#
# Warning: do not edit this file.
#
# </auto-generated>
#

from sys import version_info as _version_info_
import Ice, IcePy
import omero_model_IObject_ice
import omero_RTypes_ice
import omero_model_RTypes_ice
import omero_System_ice
import omero_Collections_ice

# Included module omero
_M_omero = Ice.openModule('omero')

# Included module omero.model
_M_omero.model = Ice.openModule('omero.model')

# Included module Ice
_M_Ice = Ice.openModule('Ice')

# Included module omero.sys
_M_omero.sys = Ice.openModule('omero.sys')

# Included module omero.api
_M_omero.api = Ice.openModule('omero.api')

# Start of module omero
__name__ = 'omero'

# Start of module omero.model
__name__ = 'omero.model'

if 'ProjectDatasetLink' not in _M_omero.model.__dict__:
    _M_omero.model._t_ProjectDatasetLink = IcePy.declareClass('::omero::model::ProjectDatasetLink')
    _M_omero.model._t_ProjectDatasetLinkPrx = IcePy.declareProxy('::omero::model::ProjectDatasetLink')

if 'Dataset' not in _M_omero.model.__dict__:
    _M_omero.model._t_Dataset = IcePy.declareClass('::omero::model::Dataset')
    _M_omero.model._t_DatasetPrx = IcePy.declareProxy('::omero::model::Dataset')

if 'ProjectAnnotationLink' not in _M_omero.model.__dict__:
    _M_omero.model._t_ProjectAnnotationLink = IcePy.declareClass('::omero::model::ProjectAnnotationLink')
    _M_omero.model._t_ProjectAnnotationLinkPrx = IcePy.declareProxy('::omero::model::ProjectAnnotationLink')

if 'Annotation' not in _M_omero.model.__dict__:
    _M_omero.model._t_Annotation = IcePy.declareClass('::omero::model::Annotation')
    _M_omero.model._t_AnnotationPrx = IcePy.declareProxy('::omero::model::Annotation')

if 'Details' not in _M_omero.model.__dict__:
    _M_omero.model._t_Details = IcePy.declareClass('::omero::model::Details')
    _M_omero.model._t_DetailsPrx = IcePy.declareProxy('::omero::model::Details')

if '_t_ProjectDatasetLinksSeq' not in _M_omero.model.__dict__:
    _M_omero.model._t_ProjectDatasetLinksSeq = IcePy.defineSequence('::omero::model::ProjectDatasetLinksSeq', (), _M_omero.model._t_ProjectDatasetLink)

if '_t_ProjectLinkedDatasetSeq' not in _M_omero.model.__dict__:
    _M_omero.model._t_ProjectLinkedDatasetSeq = IcePy.defineSequence('::omero::model::ProjectLinkedDatasetSeq', (), _M_omero.model._t_Dataset)

if '_t_ProjectAnnotationLinksSeq' not in _M_omero.model.__dict__:
    _M_omero.model._t_ProjectAnnotationLinksSeq = IcePy.defineSequence('::omero::model::ProjectAnnotationLinksSeq', (), _M_omero.model._t_ProjectAnnotationLink)

if '_t_ProjectLinkedAnnotationSeq' not in _M_omero.model.__dict__:
    _M_omero.model._t_ProjectLinkedAnnotationSeq = IcePy.defineSequence('::omero::model::ProjectLinkedAnnotationSeq', (), _M_omero.model._t_Annotation)

if 'Project' not in _M_omero.model.__dict__:
    _M_omero.model.Project = Ice.createTempClass()
    class Project(_M_omero.model.IObject):
        def __init__(self, _id=None, _details=None, _loaded=False, _version=None, _datasetLinksSeq=None, _datasetLinksLoaded=False, _datasetLinksCountPerOwner=None, _annotationLinksSeq=None, _annotationLinksLoaded=False, _annotationLinksCountPerOwner=None, _name=None, _description=None):
            if Ice.getType(self) == _M_omero.model.Project:
                raise RuntimeError('omero.model.Project is an abstract class')
            _M_omero.model.IObject.__init__(self, _id, _details, _loaded)
            self._version = _version
            self._datasetLinksSeq = _datasetLinksSeq
            self._datasetLinksLoaded = _datasetLinksLoaded
            self._datasetLinksCountPerOwner = _datasetLinksCountPerOwner
            self._annotationLinksSeq = _annotationLinksSeq
            self._annotationLinksLoaded = _annotationLinksLoaded
            self._annotationLinksCountPerOwner = _annotationLinksCountPerOwner
            self._name = _name
            self._description = _description

        def ice_ids(self, current=None):
            return ('::Ice::Object', '::omero::model::IObject', '::omero::model::Project')

        def ice_id(self, current=None):
            return '::omero::model::Project'

        def ice_staticId():
            return '::omero::model::Project'
        ice_staticId = staticmethod(ice_staticId)

        def getVersion(self, current=None):
            pass

        def setVersion(self, theVersion, current=None):
            pass

        def unloadDatasetLinks(self, current=None):
            pass

        def sizeOfDatasetLinks(self, current=None):
            pass

        def copyDatasetLinks(self, current=None):
            pass

        def addProjectDatasetLink(self, target, current=None):
            pass

        def addAllProjectDatasetLinkSet(self, targets, current=None):
            pass

        def removeProjectDatasetLink(self, theTarget, current=None):
            pass

        def removeAllProjectDatasetLinkSet(self, targets, current=None):
            pass

        def clearDatasetLinks(self, current=None):
            pass

        def reloadDatasetLinks(self, toCopy, current=None):
            pass

        def getDatasetLinksCountPerOwner(self, current=None):
            pass

        def linkDataset(self, addition, current=None):
            pass

        def addProjectDatasetLinkToBoth(self, link, bothSides, current=None):
            pass

        def findProjectDatasetLink(self, removal, current=None):
            pass

        def unlinkDataset(self, removal, current=None):
            pass

        def removeProjectDatasetLinkFromBoth(self, link, bothSides, current=None):
            pass

        def linkedDatasetList(self, current=None):
            pass

        def unloadAnnotationLinks(self, current=None):
            pass

        def sizeOfAnnotationLinks(self, current=None):
            pass

        def copyAnnotationLinks(self, current=None):
            pass

        def addProjectAnnotationLink(self, target, current=None):
            pass

        def addAllProjectAnnotationLinkSet(self, targets, current=None):
            pass

        def removeProjectAnnotationLink(self, theTarget, current=None):
            pass

        def removeAllProjectAnnotationLinkSet(self, targets, current=None):
            pass

        def clearAnnotationLinks(self, current=None):
            pass

        def reloadAnnotationLinks(self, toCopy, current=None):
            pass

        def getAnnotationLinksCountPerOwner(self, current=None):
            pass

        def linkAnnotation(self, addition, current=None):
            pass

        def addProjectAnnotationLinkToBoth(self, link, bothSides, current=None):
            pass

        def findProjectAnnotationLink(self, removal, current=None):
            pass

        def unlinkAnnotation(self, removal, current=None):
            pass

        def removeProjectAnnotationLinkFromBoth(self, link, bothSides, current=None):
            pass

        def linkedAnnotationList(self, current=None):
            pass

        def getName(self, current=None):
            pass

        def setName(self, theName, current=None):
            pass

        def getDescription(self, current=None):
            pass

        def setDescription(self, theDescription, current=None):
            pass

        def __str__(self):
            return IcePy.stringify(self, _M_omero.model._t_Project)

        __repr__ = __str__

    _M_omero.model.ProjectPrx = Ice.createTempClass()
    class ProjectPrx(_M_omero.model.IObjectPrx):

        def getVersion(self, _ctx=None):
            return _M_omero.model.Project._op_getVersion.invoke(self, ((), _ctx))

        def begin_getVersion(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Project._op_getVersion.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getVersion(self, _r):
            return _M_omero.model.Project._op_getVersion.end(self, _r)

        def setVersion(self, theVersion, _ctx=None):
            return _M_omero.model.Project._op_setVersion.invoke(self, ((theVersion, ), _ctx))

        def begin_setVersion(self, theVersion, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Project._op_setVersion.begin(self, ((theVersion, ), _response, _ex, _sent, _ctx))

        def end_setVersion(self, _r):
            return _M_omero.model.Project._op_setVersion.end(self, _r)

        def unloadDatasetLinks(self, _ctx=None):
            return _M_omero.model.Project._op_unloadDatasetLinks.invoke(self, ((), _ctx))

        def begin_unloadDatasetLinks(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Project._op_unloadDatasetLinks.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_unloadDatasetLinks(self, _r):
            return _M_omero.model.Project._op_unloadDatasetLinks.end(self, _r)

        def sizeOfDatasetLinks(self, _ctx=None):
            return _M_omero.model.Project._op_sizeOfDatasetLinks.invoke(self, ((), _ctx))

        def begin_sizeOfDatasetLinks(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Project._op_sizeOfDatasetLinks.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_sizeOfDatasetLinks(self, _r):
            return _M_omero.model.Project._op_sizeOfDatasetLinks.end(self, _r)

        def copyDatasetLinks(self, _ctx=None):
            return _M_omero.model.Project._op_copyDatasetLinks.invoke(self, ((), _ctx))

        def begin_copyDatasetLinks(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Project._op_copyDatasetLinks.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_copyDatasetLinks(self, _r):
            return _M_omero.model.Project._op_copyDatasetLinks.end(self, _r)

        def addProjectDatasetLink(self, target, _ctx=None):
            return _M_omero.model.Project._op_addProjectDatasetLink.invoke(self, ((target, ), _ctx))

        def begin_addProjectDatasetLink(self, target, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Project._op_addProjectDatasetLink.begin(self, ((target, ), _response, _ex, _sent, _ctx))

        def end_addProjectDatasetLink(self, _r):
            return _M_omero.model.Project._op_addProjectDatasetLink.end(self, _r)

        def addAllProjectDatasetLinkSet(self, targets, _ctx=None):
            return _M_omero.model.Project._op_addAllProjectDatasetLinkSet.invoke(self, ((targets, ), _ctx))

        def begin_addAllProjectDatasetLinkSet(self, targets, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Project._op_addAllProjectDatasetLinkSet.begin(self, ((targets, ), _response, _ex, _sent, _ctx))

        def end_addAllProjectDatasetLinkSet(self, _r):
            return _M_omero.model.Project._op_addAllProjectDatasetLinkSet.end(self, _r)

        def removeProjectDatasetLink(self, theTarget, _ctx=None):
            return _M_omero.model.Project._op_removeProjectDatasetLink.invoke(self, ((theTarget, ), _ctx))

        def begin_removeProjectDatasetLink(self, theTarget, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Project._op_removeProjectDatasetLink.begin(self, ((theTarget, ), _response, _ex, _sent, _ctx))

        def end_removeProjectDatasetLink(self, _r):
            return _M_omero.model.Project._op_removeProjectDatasetLink.end(self, _r)

        def removeAllProjectDatasetLinkSet(self, targets, _ctx=None):
            return _M_omero.model.Project._op_removeAllProjectDatasetLinkSet.invoke(self, ((targets, ), _ctx))

        def begin_removeAllProjectDatasetLinkSet(self, targets, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Project._op_removeAllProjectDatasetLinkSet.begin(self, ((targets, ), _response, _ex, _sent, _ctx))

        def end_removeAllProjectDatasetLinkSet(self, _r):
            return _M_omero.model.Project._op_removeAllProjectDatasetLinkSet.end(self, _r)

        def clearDatasetLinks(self, _ctx=None):
            return _M_omero.model.Project._op_clearDatasetLinks.invoke(self, ((), _ctx))

        def begin_clearDatasetLinks(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Project._op_clearDatasetLinks.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_clearDatasetLinks(self, _r):
            return _M_omero.model.Project._op_clearDatasetLinks.end(self, _r)

        def reloadDatasetLinks(self, toCopy, _ctx=None):
            return _M_omero.model.Project._op_reloadDatasetLinks.invoke(self, ((toCopy, ), _ctx))

        def begin_reloadDatasetLinks(self, toCopy, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Project._op_reloadDatasetLinks.begin(self, ((toCopy, ), _response, _ex, _sent, _ctx))

        def end_reloadDatasetLinks(self, _r):
            return _M_omero.model.Project._op_reloadDatasetLinks.end(self, _r)

        def getDatasetLinksCountPerOwner(self, _ctx=None):
            return _M_omero.model.Project._op_getDatasetLinksCountPerOwner.invoke(self, ((), _ctx))

        def begin_getDatasetLinksCountPerOwner(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Project._op_getDatasetLinksCountPerOwner.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getDatasetLinksCountPerOwner(self, _r):
            return _M_omero.model.Project._op_getDatasetLinksCountPerOwner.end(self, _r)

        def linkDataset(self, addition, _ctx=None):
            return _M_omero.model.Project._op_linkDataset.invoke(self, ((addition, ), _ctx))

        def begin_linkDataset(self, addition, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Project._op_linkDataset.begin(self, ((addition, ), _response, _ex, _sent, _ctx))

        def end_linkDataset(self, _r):
            return _M_omero.model.Project._op_linkDataset.end(self, _r)

        def addProjectDatasetLinkToBoth(self, link, bothSides, _ctx=None):
            return _M_omero.model.Project._op_addProjectDatasetLinkToBoth.invoke(self, ((link, bothSides), _ctx))

        def begin_addProjectDatasetLinkToBoth(self, link, bothSides, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Project._op_addProjectDatasetLinkToBoth.begin(self, ((link, bothSides), _response, _ex, _sent, _ctx))

        def end_addProjectDatasetLinkToBoth(self, _r):
            return _M_omero.model.Project._op_addProjectDatasetLinkToBoth.end(self, _r)

        def findProjectDatasetLink(self, removal, _ctx=None):
            return _M_omero.model.Project._op_findProjectDatasetLink.invoke(self, ((removal, ), _ctx))

        def begin_findProjectDatasetLink(self, removal, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Project._op_findProjectDatasetLink.begin(self, ((removal, ), _response, _ex, _sent, _ctx))

        def end_findProjectDatasetLink(self, _r):
            return _M_omero.model.Project._op_findProjectDatasetLink.end(self, _r)

        def unlinkDataset(self, removal, _ctx=None):
            return _M_omero.model.Project._op_unlinkDataset.invoke(self, ((removal, ), _ctx))

        def begin_unlinkDataset(self, removal, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Project._op_unlinkDataset.begin(self, ((removal, ), _response, _ex, _sent, _ctx))

        def end_unlinkDataset(self, _r):
            return _M_omero.model.Project._op_unlinkDataset.end(self, _r)

        def removeProjectDatasetLinkFromBoth(self, link, bothSides, _ctx=None):
            return _M_omero.model.Project._op_removeProjectDatasetLinkFromBoth.invoke(self, ((link, bothSides), _ctx))

        def begin_removeProjectDatasetLinkFromBoth(self, link, bothSides, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Project._op_removeProjectDatasetLinkFromBoth.begin(self, ((link, bothSides), _response, _ex, _sent, _ctx))

        def end_removeProjectDatasetLinkFromBoth(self, _r):
            return _M_omero.model.Project._op_removeProjectDatasetLinkFromBoth.end(self, _r)

        def linkedDatasetList(self, _ctx=None):
            return _M_omero.model.Project._op_linkedDatasetList.invoke(self, ((), _ctx))

        def begin_linkedDatasetList(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Project._op_linkedDatasetList.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_linkedDatasetList(self, _r):
            return _M_omero.model.Project._op_linkedDatasetList.end(self, _r)

        def unloadAnnotationLinks(self, _ctx=None):
            return _M_omero.model.Project._op_unloadAnnotationLinks.invoke(self, ((), _ctx))

        def begin_unloadAnnotationLinks(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Project._op_unloadAnnotationLinks.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_unloadAnnotationLinks(self, _r):
            return _M_omero.model.Project._op_unloadAnnotationLinks.end(self, _r)

        def sizeOfAnnotationLinks(self, _ctx=None):
            return _M_omero.model.Project._op_sizeOfAnnotationLinks.invoke(self, ((), _ctx))

        def begin_sizeOfAnnotationLinks(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Project._op_sizeOfAnnotationLinks.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_sizeOfAnnotationLinks(self, _r):
            return _M_omero.model.Project._op_sizeOfAnnotationLinks.end(self, _r)

        def copyAnnotationLinks(self, _ctx=None):
            return _M_omero.model.Project._op_copyAnnotationLinks.invoke(self, ((), _ctx))

        def begin_copyAnnotationLinks(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Project._op_copyAnnotationLinks.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_copyAnnotationLinks(self, _r):
            return _M_omero.model.Project._op_copyAnnotationLinks.end(self, _r)

        def addProjectAnnotationLink(self, target, _ctx=None):
            return _M_omero.model.Project._op_addProjectAnnotationLink.invoke(self, ((target, ), _ctx))

        def begin_addProjectAnnotationLink(self, target, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Project._op_addProjectAnnotationLink.begin(self, ((target, ), _response, _ex, _sent, _ctx))

        def end_addProjectAnnotationLink(self, _r):
            return _M_omero.model.Project._op_addProjectAnnotationLink.end(self, _r)

        def addAllProjectAnnotationLinkSet(self, targets, _ctx=None):
            return _M_omero.model.Project._op_addAllProjectAnnotationLinkSet.invoke(self, ((targets, ), _ctx))

        def begin_addAllProjectAnnotationLinkSet(self, targets, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Project._op_addAllProjectAnnotationLinkSet.begin(self, ((targets, ), _response, _ex, _sent, _ctx))

        def end_addAllProjectAnnotationLinkSet(self, _r):
            return _M_omero.model.Project._op_addAllProjectAnnotationLinkSet.end(self, _r)

        def removeProjectAnnotationLink(self, theTarget, _ctx=None):
            return _M_omero.model.Project._op_removeProjectAnnotationLink.invoke(self, ((theTarget, ), _ctx))

        def begin_removeProjectAnnotationLink(self, theTarget, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Project._op_removeProjectAnnotationLink.begin(self, ((theTarget, ), _response, _ex, _sent, _ctx))

        def end_removeProjectAnnotationLink(self, _r):
            return _M_omero.model.Project._op_removeProjectAnnotationLink.end(self, _r)

        def removeAllProjectAnnotationLinkSet(self, targets, _ctx=None):
            return _M_omero.model.Project._op_removeAllProjectAnnotationLinkSet.invoke(self, ((targets, ), _ctx))

        def begin_removeAllProjectAnnotationLinkSet(self, targets, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Project._op_removeAllProjectAnnotationLinkSet.begin(self, ((targets, ), _response, _ex, _sent, _ctx))

        def end_removeAllProjectAnnotationLinkSet(self, _r):
            return _M_omero.model.Project._op_removeAllProjectAnnotationLinkSet.end(self, _r)

        def clearAnnotationLinks(self, _ctx=None):
            return _M_omero.model.Project._op_clearAnnotationLinks.invoke(self, ((), _ctx))

        def begin_clearAnnotationLinks(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Project._op_clearAnnotationLinks.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_clearAnnotationLinks(self, _r):
            return _M_omero.model.Project._op_clearAnnotationLinks.end(self, _r)

        def reloadAnnotationLinks(self, toCopy, _ctx=None):
            return _M_omero.model.Project._op_reloadAnnotationLinks.invoke(self, ((toCopy, ), _ctx))

        def begin_reloadAnnotationLinks(self, toCopy, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Project._op_reloadAnnotationLinks.begin(self, ((toCopy, ), _response, _ex, _sent, _ctx))

        def end_reloadAnnotationLinks(self, _r):
            return _M_omero.model.Project._op_reloadAnnotationLinks.end(self, _r)

        def getAnnotationLinksCountPerOwner(self, _ctx=None):
            return _M_omero.model.Project._op_getAnnotationLinksCountPerOwner.invoke(self, ((), _ctx))

        def begin_getAnnotationLinksCountPerOwner(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Project._op_getAnnotationLinksCountPerOwner.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getAnnotationLinksCountPerOwner(self, _r):
            return _M_omero.model.Project._op_getAnnotationLinksCountPerOwner.end(self, _r)

        def linkAnnotation(self, addition, _ctx=None):
            return _M_omero.model.Project._op_linkAnnotation.invoke(self, ((addition, ), _ctx))

        def begin_linkAnnotation(self, addition, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Project._op_linkAnnotation.begin(self, ((addition, ), _response, _ex, _sent, _ctx))

        def end_linkAnnotation(self, _r):
            return _M_omero.model.Project._op_linkAnnotation.end(self, _r)

        def addProjectAnnotationLinkToBoth(self, link, bothSides, _ctx=None):
            return _M_omero.model.Project._op_addProjectAnnotationLinkToBoth.invoke(self, ((link, bothSides), _ctx))

        def begin_addProjectAnnotationLinkToBoth(self, link, bothSides, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Project._op_addProjectAnnotationLinkToBoth.begin(self, ((link, bothSides), _response, _ex, _sent, _ctx))

        def end_addProjectAnnotationLinkToBoth(self, _r):
            return _M_omero.model.Project._op_addProjectAnnotationLinkToBoth.end(self, _r)

        def findProjectAnnotationLink(self, removal, _ctx=None):
            return _M_omero.model.Project._op_findProjectAnnotationLink.invoke(self, ((removal, ), _ctx))

        def begin_findProjectAnnotationLink(self, removal, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Project._op_findProjectAnnotationLink.begin(self, ((removal, ), _response, _ex, _sent, _ctx))

        def end_findProjectAnnotationLink(self, _r):
            return _M_omero.model.Project._op_findProjectAnnotationLink.end(self, _r)

        def unlinkAnnotation(self, removal, _ctx=None):
            return _M_omero.model.Project._op_unlinkAnnotation.invoke(self, ((removal, ), _ctx))

        def begin_unlinkAnnotation(self, removal, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Project._op_unlinkAnnotation.begin(self, ((removal, ), _response, _ex, _sent, _ctx))

        def end_unlinkAnnotation(self, _r):
            return _M_omero.model.Project._op_unlinkAnnotation.end(self, _r)

        def removeProjectAnnotationLinkFromBoth(self, link, bothSides, _ctx=None):
            return _M_omero.model.Project._op_removeProjectAnnotationLinkFromBoth.invoke(self, ((link, bothSides), _ctx))

        def begin_removeProjectAnnotationLinkFromBoth(self, link, bothSides, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Project._op_removeProjectAnnotationLinkFromBoth.begin(self, ((link, bothSides), _response, _ex, _sent, _ctx))

        def end_removeProjectAnnotationLinkFromBoth(self, _r):
            return _M_omero.model.Project._op_removeProjectAnnotationLinkFromBoth.end(self, _r)

        def linkedAnnotationList(self, _ctx=None):
            return _M_omero.model.Project._op_linkedAnnotationList.invoke(self, ((), _ctx))

        def begin_linkedAnnotationList(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Project._op_linkedAnnotationList.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_linkedAnnotationList(self, _r):
            return _M_omero.model.Project._op_linkedAnnotationList.end(self, _r)

        def getName(self, _ctx=None):
            return _M_omero.model.Project._op_getName.invoke(self, ((), _ctx))

        def begin_getName(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Project._op_getName.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getName(self, _r):
            return _M_omero.model.Project._op_getName.end(self, _r)

        def setName(self, theName, _ctx=None):
            return _M_omero.model.Project._op_setName.invoke(self, ((theName, ), _ctx))

        def begin_setName(self, theName, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Project._op_setName.begin(self, ((theName, ), _response, _ex, _sent, _ctx))

        def end_setName(self, _r):
            return _M_omero.model.Project._op_setName.end(self, _r)

        def getDescription(self, _ctx=None):
            return _M_omero.model.Project._op_getDescription.invoke(self, ((), _ctx))

        def begin_getDescription(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Project._op_getDescription.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getDescription(self, _r):
            return _M_omero.model.Project._op_getDescription.end(self, _r)

        def setDescription(self, theDescription, _ctx=None):
            return _M_omero.model.Project._op_setDescription.invoke(self, ((theDescription, ), _ctx))

        def begin_setDescription(self, theDescription, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Project._op_setDescription.begin(self, ((theDescription, ), _response, _ex, _sent, _ctx))

        def end_setDescription(self, _r):
            return _M_omero.model.Project._op_setDescription.end(self, _r)

        def checkedCast(proxy, facetOrCtx=None, _ctx=None):
            return _M_omero.model.ProjectPrx.ice_checkedCast(proxy, '::omero::model::Project', facetOrCtx, _ctx)
        checkedCast = staticmethod(checkedCast)

        def uncheckedCast(proxy, facet=None):
            return _M_omero.model.ProjectPrx.ice_uncheckedCast(proxy, facet)
        uncheckedCast = staticmethod(uncheckedCast)

        def ice_staticId():
            return '::omero::model::Project'
        ice_staticId = staticmethod(ice_staticId)

    _M_omero.model._t_ProjectPrx = IcePy.defineProxy('::omero::model::Project', ProjectPrx)

    _M_omero.model._t_Project = IcePy.declareClass('::omero::model::Project')

    _M_omero.model._t_Project = IcePy.defineClass('::omero::model::Project', Project, -1, (), True, False, _M_omero.model._t_IObject, (), (
        ('_version', (), _M_omero._t_RInt, False, 0),
        ('_datasetLinksSeq', (), _M_omero.model._t_ProjectDatasetLinksSeq, False, 0),
        ('_datasetLinksLoaded', (), IcePy._t_bool, False, 0),
        ('_datasetLinksCountPerOwner', (), _M_omero.sys._t_CountMap, False, 0),
        ('_annotationLinksSeq', (), _M_omero.model._t_ProjectAnnotationLinksSeq, False, 0),
        ('_annotationLinksLoaded', (), IcePy._t_bool, False, 0),
        ('_annotationLinksCountPerOwner', (), _M_omero.sys._t_CountMap, False, 0),
        ('_name', (), _M_omero._t_RString, False, 0),
        ('_description', (), _M_omero._t_RString, False, 0)
    ))
    Project._ice_type = _M_omero.model._t_Project

    Project._op_getVersion = IcePy.Operation('getVersion', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RInt, False, 0), ())
    Project._op_setVersion = IcePy.Operation('setVersion', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RInt, False, 0),), (), None, ())
    Project._op_unloadDatasetLinks = IcePy.Operation('unloadDatasetLinks', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), None, ())
    Project._op_sizeOfDatasetLinks = IcePy.Operation('sizeOfDatasetLinks', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), IcePy._t_int, False, 0), ())
    Project._op_copyDatasetLinks = IcePy.Operation('copyDatasetLinks', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_ProjectDatasetLinksSeq, False, 0), ())
    Project._op_addProjectDatasetLink = IcePy.Operation('addProjectDatasetLink', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_ProjectDatasetLink, False, 0),), (), None, ())
    Project._op_addAllProjectDatasetLinkSet = IcePy.Operation('addAllProjectDatasetLinkSet', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_ProjectDatasetLinksSeq, False, 0),), (), None, ())
    Project._op_removeProjectDatasetLink = IcePy.Operation('removeProjectDatasetLink', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_ProjectDatasetLink, False, 0),), (), None, ())
    Project._op_removeAllProjectDatasetLinkSet = IcePy.Operation('removeAllProjectDatasetLinkSet', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_ProjectDatasetLinksSeq, False, 0),), (), None, ())
    Project._op_clearDatasetLinks = IcePy.Operation('clearDatasetLinks', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), None, ())
    Project._op_reloadDatasetLinks = IcePy.Operation('reloadDatasetLinks', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Project, False, 0),), (), None, ())
    Project._op_getDatasetLinksCountPerOwner = IcePy.Operation('getDatasetLinksCountPerOwner', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.sys._t_CountMap, False, 0), ())
    Project._op_linkDataset = IcePy.Operation('linkDataset', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Dataset, False, 0),), (), ((), _M_omero.model._t_ProjectDatasetLink, False, 0), ())
    Project._op_addProjectDatasetLinkToBoth = IcePy.Operation('addProjectDatasetLinkToBoth', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_ProjectDatasetLink, False, 0), ((), IcePy._t_bool, False, 0)), (), None, ())
    Project._op_findProjectDatasetLink = IcePy.Operation('findProjectDatasetLink', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Dataset, False, 0),), (), ((), _M_omero.model._t_ProjectDatasetLinksSeq, False, 0), ())
    Project._op_unlinkDataset = IcePy.Operation('unlinkDataset', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Dataset, False, 0),), (), None, ())
    Project._op_removeProjectDatasetLinkFromBoth = IcePy.Operation('removeProjectDatasetLinkFromBoth', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_ProjectDatasetLink, False, 0), ((), IcePy._t_bool, False, 0)), (), None, ())
    Project._op_linkedDatasetList = IcePy.Operation('linkedDatasetList', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_ProjectLinkedDatasetSeq, False, 0), ())
    Project._op_unloadAnnotationLinks = IcePy.Operation('unloadAnnotationLinks', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), None, ())
    Project._op_sizeOfAnnotationLinks = IcePy.Operation('sizeOfAnnotationLinks', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), IcePy._t_int, False, 0), ())
    Project._op_copyAnnotationLinks = IcePy.Operation('copyAnnotationLinks', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_ProjectAnnotationLinksSeq, False, 0), ())
    Project._op_addProjectAnnotationLink = IcePy.Operation('addProjectAnnotationLink', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_ProjectAnnotationLink, False, 0),), (), None, ())
    Project._op_addAllProjectAnnotationLinkSet = IcePy.Operation('addAllProjectAnnotationLinkSet', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_ProjectAnnotationLinksSeq, False, 0),), (), None, ())
    Project._op_removeProjectAnnotationLink = IcePy.Operation('removeProjectAnnotationLink', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_ProjectAnnotationLink, False, 0),), (), None, ())
    Project._op_removeAllProjectAnnotationLinkSet = IcePy.Operation('removeAllProjectAnnotationLinkSet', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_ProjectAnnotationLinksSeq, False, 0),), (), None, ())
    Project._op_clearAnnotationLinks = IcePy.Operation('clearAnnotationLinks', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), None, ())
    Project._op_reloadAnnotationLinks = IcePy.Operation('reloadAnnotationLinks', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Project, False, 0),), (), None, ())
    Project._op_getAnnotationLinksCountPerOwner = IcePy.Operation('getAnnotationLinksCountPerOwner', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.sys._t_CountMap, False, 0), ())
    Project._op_linkAnnotation = IcePy.Operation('linkAnnotation', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Annotation, False, 0),), (), ((), _M_omero.model._t_ProjectAnnotationLink, False, 0), ())
    Project._op_addProjectAnnotationLinkToBoth = IcePy.Operation('addProjectAnnotationLinkToBoth', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_ProjectAnnotationLink, False, 0), ((), IcePy._t_bool, False, 0)), (), None, ())
    Project._op_findProjectAnnotationLink = IcePy.Operation('findProjectAnnotationLink', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Annotation, False, 0),), (), ((), _M_omero.model._t_ProjectAnnotationLinksSeq, False, 0), ())
    Project._op_unlinkAnnotation = IcePy.Operation('unlinkAnnotation', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Annotation, False, 0),), (), None, ())
    Project._op_removeProjectAnnotationLinkFromBoth = IcePy.Operation('removeProjectAnnotationLinkFromBoth', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_ProjectAnnotationLink, False, 0), ((), IcePy._t_bool, False, 0)), (), None, ())
    Project._op_linkedAnnotationList = IcePy.Operation('linkedAnnotationList', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_ProjectLinkedAnnotationSeq, False, 0), ())
    Project._op_getName = IcePy.Operation('getName', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RString, False, 0), ())
    Project._op_setName = IcePy.Operation('setName', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RString, False, 0),), (), None, ())
    Project._op_getDescription = IcePy.Operation('getDescription', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RString, False, 0), ())
    Project._op_setDescription = IcePy.Operation('setDescription', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RString, False, 0),), (), None, ())

    _M_omero.model.Project = Project
    del Project

    _M_omero.model.ProjectPrx = ProjectPrx
    del ProjectPrx

# End of module omero.model

__name__ = 'omero'

# End of module omero



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import IceImport
IceImport.load("omero_FS_ice")

#
# Copied from:
# blitz/src/ome/formats/importer/transfers/AbstractFileTransfer.java
#
TRANSFERS = {
    "ome.formats.importer.transfers.CopyFileTransfer": "cp",
    "ome.formats.importer.transfers.CopyMoveFileTransfer": "cp_rm",
    "ome.formats.importer.transfers.HardlinkFileTransfer": "ln",
    "ome.formats.importer.transfers.MoveFileTransfer": "ln_rm",
    "ome.formats.importer.transfers.SymlinkFileTransfer": "ln_s",
    "ome.formats.importer.transfers.UploadRmFileTransfer": "upload_rm",
    "ome.formats.importer.transfers.UploadFileTransfer": "",
    }



#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
#
# ------------------------------------------------------------------------------
#  Copyright (C) 2006-2016 University of Dundee. All rights reserved.
#
#
#   This program is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 2 of the License, or
#  (at your option) any later version.
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License along
#  with this program; if not, write to the Free Software Foundation, Inc.,
#  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
#
# ------------------------------------------------------------------------------
# @author  Jean-Marie Burel &nbsp;&nbsp;&nbsp;&nbsp;
#   <a href="mailto:j.burel@dundee.ac.uk">j.burel@dundee.ac.uk</a>
# @author   Donald MacDonald &nbsp;&nbsp;&nbsp;&nbsp;
#   <a href="mailto:donald@lifesci.dundee.ac.uk">donald@lifesci.dundee.ac.uk
#   </a>
#

"""
ROIUtils allows the mapping of omero.model.ROIDataTypesI to python types
and to create ROIDataTypesI from ROIUtil types.

These methods also implement the acceptVisitor method linking to
the ROIDrawingCanvas.
"""

from __future__ import division
from builtins import str
from builtins import map
from builtins import range
from past.utils import old_div
from builtins import object
from omero.model.enums import UnitsLength
from omero.model import LengthI
from omero.model import EllipseI
from omero.model import LineI
from omero.model import RectangleI
from omero.model import PointI
from omero.model import PolylineI
from omero.model import PolygonI
from omero.model import MaskI
from omero.rtypes import rdouble, rint, rstring

import warnings
#
# HELPERS
#


def pointsStringToXYlist(string):
    """
    Method for converting the string returned from
    omero.model.ShapeI.getPoints() into list of (x,y) points.
    E.g: "points[309,427, 366,503, 190,491] points1[309,427, 366,503,
    190,491] points2[309,427, 366,503, 190,491]"
    or the new format: "309,427 366,503 190,491"
    """
    warnings.warn(
        "This module is deprecated as of OMERO 5.3.0", DeprecationWarning)
    pointLists = string.strip().split("points")
    if len(pointLists) < 2:
        if len(pointLists) == 1 and pointLists[0]:
            xys = pointLists[0].split()
            xyList = [tuple(map(int, xy.split(','))) for xy in xys]
            return xyList

        msg = "Unrecognised ROI shape 'points' string: %s" % string
        raise ValueError(msg)

    firstList = pointLists[1]
    xyList = []
    for xy in firstList.strip(" []").split(", "):
        x, y = xy.split(",")
        xyList.append((int(x.strip()), int(y.strip())))
    return xyList


def xyListToBbox(xyList):
    """
    Returns a bounding box (x,y,w,h) that will contain the shape
    represented by the XY points list
    """
    warnings.warn(
        "This module is deprecated as of OMERO 5.3.0", DeprecationWarning)
    xList, yList = [], []
    for xy in xyList:
        x, y = xy
        xList.append(x)
        yList.append(y)
    return (min(xList), min(yList), max(xList)-min(xList),
            max(yList)-min(yList))


#
# Data implementation
#

##
# abstract, defines the method that call it as abstract.
#
#
def abstract():
    import inspect
    caller = inspect.getouterframes(inspect.currentframe())[1][3]
    raise NotImplementedError(caller + ' must be implemented in subclass')

##
# ShapeSettingsData contains all the display information about
# the ROI that aggregates it.
#


class ShapeSettingsData(object):

    ##
    # Initialises the default values of the ShapeSettings.
    # Stroke has default colour of darkGrey
    # StrokeWidth defaults to 1
    #

    def __init__(self):
        warnings.warn(
            "This module is deprecated as of OMERO 5.3.0", DeprecationWarning)
        self.WHITE = 16777215
        self.BLACK = 0
        self.GREY = 11184810
        self.strokeColour = rint(self.GREY)
        self.strokeWidth = LengthI()
        self.strokeWidth.setValue(1)
        self.strokeWidth.setUnit(UnitsLength.POINT)
        self.strokeDashArray = rstring('')
        self.fillColour = rint(self.GREY)
        self.fillRule = rstring('')

    ##
    # Applies the settings in the ShapeSettingsData to the ROITypeI
    # @param shape the omero.model.ROITypeI that these settings will
    #              be applied to
    #
    def setROIShapeSettings(self, shape):
        warnings.warn(
            "This module is deprecated as of OMERO 5.3.0", DeprecationWarning)
        shape.setStrokeColor(self.strokeColour)
        shape.setStrokeWidth(self.strokeWidth)
        shape.setStrokeDashArray(self.strokeDashArray)
        shape.setFillColor(self.fillColour)
        shape.setFillRule(self.fillRule)

    ##
    # Set the Stroke settings of the ShapeSettings.
    # @param colour The colour of the stroke.
    # @param width The stroke width.
    #
    def setStrokeSettings(self, colour, width=1):
        warnings.warn(
            "This module is deprecated as of OMERO 5.3.0", DeprecationWarning)
        self.strokeColour = rint(colour)
        self.strokeWidth = LengthI()
        self.strokeWidth.setValue(width)
        self.strokeWidth.setUnit(UnitsLength.POINT)

    ###
    # Set the Fill Settings for the ShapeSettings.
    # @param colour The fill colour of the shape.
    def setFillSettings(self, colour):
        warnings.warn(
            "This module is deprecated as of OMERO 5.3.0", DeprecationWarning)
        self.fillColour = rstring(colour)

    ##
    # Get the stroke settings as the tuple (strokeColour, strokeWidth).
    # @return See above.
    #
    def getStrokeSettings(self):
        warnings.warn(
            "This module is deprecated as of OMERO 5.3.0", DeprecationWarning)
        return (self.strokeColour.getValue(), self.strokeWidth.getValue())

    ##
    # Get the fill setting as a tuple of (fillColour)
    # @return See above.
    #
    def getFillSettings(self):
        warnings.warn(
            "This module is deprecated as of OMERO 5.3.0", DeprecationWarning)
        return (self.fillColour.getValue())

    ##
    # Get the tuple ((stokeColor, strokeWidth), (fillColour)).
    # @return see above.
    #
    def getSettings(self):
        warnings.warn(
            "This module is deprecated as of OMERO 5.3.0", DeprecationWarning)
        return (self.getStrokeSettings(), self.getFillSettings())

    ##
    # Set the current shapeSettings from the ROI roi.
    # @param roi see above.
    #
    def getShapeSettingsFromROI(self, roi):
        warnings.warn(
            "This module is deprecated as of OMERO 5.3.0", DeprecationWarning)
        self.strokeColour = roi.getStrokeColor()
        self.strokeWidth = roi.getStrokeWidth()
        self.strokeDashArray = roi.getStrokeDashArray()
        self.fillColour = roi.getFillColor()
        self.fillRule = roi.getFillRule()

##
# This class stores the ROI Coordinate (Z,T).
#


class ROICoordinate(object):

    ##
    # Initialise the ROICoordinate.
    # @param z The z-section.
    # @param t The timepoint.

    def __init__(self, z=0, t=0):
        warnings.warn(
            "This module is deprecated as of OMERO 5.3.0", DeprecationWarning)
        self.theZ = rint(z)
        self.theT = rint(t)

    ##
    # Set the (z, t) for the roi using the (z, t) of the ROICoordinate.
    # @param roi The ROI to set the (z, t) on.
    #
    def setROICoord(self, roi):
        warnings.warn(
            "This module is deprecated as of OMERO 5.3.0", DeprecationWarning)
        roi.setTheZ(self.theZ)
        roi.setTheT(self.theT)

    ##
    # Get the (z, t) from the ROI.
    # @param See above.
    #
    def setCoordFromROI(self, roi):
        warnings.warn(
            "This module is deprecated as of OMERO 5.3.0", DeprecationWarning)
        self.theZ = roi.getTheZ()
        self.theT = roi.getTheT()

##
# Interface to inherit for accepting ROIDrawing as a visitor.
# @param visitor The ROIDrawingCompoent.
#


class ROIDrawingI(object):

    def acceptVisitor(self, visitor):
        warnings.warn(
            "This module is deprecated as of OMERO 5.3.0", DeprecationWarning)
        abstract()

##
# The base class for all ROIShapeData objects.
#


class ShapeData(object):

    ##
    # Constructor sets up the coord, shapeSettings and ROI objects.
    #

    def __init__(self):
        warnings.warn(
            "This module is deprecated as of OMERO 5.3.0", DeprecationWarning)
        self.coord = ROICoordinate()
        self.shapeSettings = ShapeSettingsData()
        self.ROI = None

    ##
    # Set the coord of the class to coord.
    # @param See above.
    #
    def setCoord(self, coord):
        warnings.warn(
            "This module is deprecated as of OMERO 5.3.0", DeprecationWarning)
        self.coord = coord

    ##
    # Set the ROICoordinate of the roi.
    # @param roi See above.
    #
    def setROICoord(self, roi):
        warnings.warn(
            "This module is deprecated as of OMERO 5.3.0", DeprecationWarning)
        self.coord.setROICoord(roi)

    ##
    # Set the Geometry of the roi from the geometry in ShapeData.
    # @param roi See above.
    #
    def setROIGeometry(self, roi):
        warnings.warn(
            "This module is deprecated as of OMERO 5.3.0", DeprecationWarning)
        abstract()

    ##
    # Set the Settings of the ShapeDate form the settings object.
    # @param settings See above.
    #
    def setShapeSettings(self, settings):
        warnings.warn(
            "This module is deprecated as of OMERO 5.3.0", DeprecationWarning)
        self.shapeSettings = settings

    ##
    # Set the Settings of the roi from the setting in ShapeData.
    # @param roi See above.
    #
    def setROIShapeSettings(self, roi):
        warnings.warn(
            "This module is deprecated as of OMERO 5.3.0", DeprecationWarning)
        self.shapeSettings.setROIShapeSettings(roi)

    ##
    # Accept visitor.
    # @param visitor See above.
    #
    def acceptVisitor(self, visitor):
        warnings.warn(
            "This module is deprecated as of OMERO 5.3.0", DeprecationWarning)
        abstract()

    ##
    # Create the base type of ROI for this shape.
    #
    def createBaseType(self):
        warnings.warn(
            "This module is deprecated as of OMERO 5.3.0", DeprecationWarning)
        abstract()

    ##
    # Get the roi from the ShapeData. If the roi already exists return it.
    # Otherwise create it from the ShapeData and return it.
    # @return See above.
    #
    def getROI(self):
        warnings.warn(
            "This module is deprecated as of OMERO 5.3.0", DeprecationWarning)
        if(self.roi is not None):
            return self.roi
        self.roi = self.createBaseType()
        self.setROICoord(self.roi)
        self.setROIGeometry(self.roi)
        self.setROIShapeSettings(self.roi)
        return self.roi

    ##
    # Set the shape settings object from the roi.
    # @param roi see above.
    #
    def getShapeSettingsFromROI(self, roi):
        warnings.warn(
            "This module is deprecated as of OMERO 5.3.0", DeprecationWarning)
        self.shapeSettings.getShapeSettingsFromROI(roi)

    ##
    # Set the ROICoordinate from the roi.
    # @param roi See above.
    #
    def getCoordFromROI(self, roi):
        warnings.warn(
            "This module is deprecated as of OMERO 5.3.0", DeprecationWarning)
        self.coord.setCoordFromROI(roi)

    ##
    # Set the Geometr from the roi.
    # @param roi See above.
    #
    def getGeometryFromROI(self, roi):
        warnings.warn(
            "This module is deprecated as of OMERO 5.3.0", DeprecationWarning)
        abstract()

    ##
    # Get all settings from the roi, Geomerty, Shapesettins, ROICoordinate.
    # @param roi See above.
    #
    def fromROI(self, roi):
        warnings.warn(
            "This module is deprecated as of OMERO 5.3.0", DeprecationWarning)
        self.roi = roi
        self.getShapeSettingsFromROI(roi)
        self.getCoordFromROI(roi)
        self.getGeometryFromROI(roi)

##
# The EllispeData class contains all the manipulation and create of EllipseI
# types.
# It also accepts the ROIDrawingUtils visitor for drawing ellipses.
#


class EllipseData(ShapeData, ROIDrawingI):

    ##
    # Constructor for EllipseData object.
    # @param roicoord The ROICoordinate of the object (default: 0,0)
    # @param x The centre x coordinate of the ellipse.
    # @param y The centre y coordinate of the ellipse.
    # @param radiusX The major axis of the ellipse.
    # @param radiusY The minor axis of the ellipse.

    def __init__(self, roicoord=ROICoordinate(), x=0, y=0, radiusX=0,
                 radiusY=0):
        warnings.warn(
            "This module is deprecated as of OMERO 5.3.0", DeprecationWarning)
        ShapeData.__init__(self)
        self.x = rdouble(x)
        self.y = rdouble(y)
        self.radiusX = rdouble(radiusX)
        self.radiusY = rdouble(radiusY)
        self.setCoord(roicoord)

    ##
    # overridden, @See ShapeData#setROIGeometry
    #
    def setROIGeometry(self, ellipse):
        warnings.warn(
            "This module is deprecated as of OMERO 5.3.0", DeprecationWarning)
        ellipse.setTheZ(self.coord.theZ)
        ellipse.setTheT(self.coord.theT)
        ellipse.setX(self.x)
        ellipse.setY(self.y)
        ellipse.setRadiusX(self.radiusX)
        ellipse.setRadiusY(self.radiusY)

    ##
    # overridden, @See ShapeData#getGeometryFromROI
    #
    def getGeometryFromROI(self, roi):
        warnings.warn(
            "This module is deprecated as of OMERO 5.3.0", DeprecationWarning)
        self.x = roi.getX()
        self.y = roi.getY()
        self.radiusX = roi.getRadiusX()
        self.radiusY = roi.getRadiusY()

    ##
    # overridden, @See ShapeData#createBaseType
    #
    def createBaseType(self):
        warnings.warn(
            "This module is deprecated as of OMERO 5.3.0", DeprecationWarning)
        return EllipseI()

    ##
    # overridden, @See ShapeData#acceptVisitor
    #
    def acceptVisitor(self, visitor):
        warnings.warn(
            "This module is deprecated as of OMERO 5.3.0", DeprecationWarning)
        visitor.drawEllipse(
            self.x.getValue(), self.y.getValue(), self.radiusX.getValue(),
            self.radiusY.getValue(), self.shapeSettings.getSettings())

##
# The RectangleData class contains all the manipulation and creation of
# RectangleI types.
# It also accepts the ROIDrawingUtils visitor for drawing rectangles.
#


class RectangleData(ShapeData, ROIDrawingI):

    ##
    # Constructor for RectangleData object.
    # @param roicoord The ROICoordinate of the object (default: 0,0)
    # @param x The top left x - coordinate of the shape.
    # @param y The top left y - coordinate of the shape.
    # @param width The width of the shape.
    # @param height The height of the shape.

    def __init__(self, roicoord=ROICoordinate(), x=0, y=0, width=0, height=0):
        warnings.warn(
            "This module is deprecated as of OMERO 5.3.0", DeprecationWarning)
        ShapeData.__init__(self)
        self.x = rdouble(x)
        self.y = rdouble(y)
        self.width = rdouble(width)
        self.height = rdouble(height)
        self.setCoord(roicoord)

    ##
    # overridden, @See ShapeData#setGeometry
    #
    def setGeometry(self, rectangle):
        warnings.warn(
            "This module is deprecated as of OMERO 5.3.0", DeprecationWarning)
        rectangle.setTheZ(self.coord.theZ)
        rectangle.setTheT(self.coord.theT)
        rectangle.setX(self.x)
        rectangle.setY(self.y)
        rectangle.setWidth(self.width)
        rectangle.setHeight(self.height)

    ##
    # overridden, @See ShapeData#getGeometryFromROI
    #
    def getGeometryFromROI(self, roi):
        warnings.warn(
            "This module is deprecated as of OMERO 5.3.0", DeprecationWarning)
        self.x = roi.getX()
        self.y = roi.getY()
        self.width = roi.getWidth()
        self.height = roi.getHeight()

    ##
    # overridden, @See ShapeData#createBaseType
    #
    def createBaseType(self):
        warnings.warn(
            "This module is deprecated as of OMERO 5.3.0", DeprecationWarning)
        return RectangleI()

    ##
    # overridden, @See ShapeData#acceptVisitor
    #
    def acceptVisitor(self, visitor):
        warnings.warn(
            "This module is deprecated as of OMERO 5.3.0", DeprecationWarning)
        visitor.drawRectangle(
            self.x, self.y, self.width, self.height,
            self.shapeSettings.getSettings())
##
# The LineData class contains all the manipulation and create of LineI
# types.
# It also accepts the ROIDrawingUtils visitor for drawing lines.
#


class LineData(ShapeData, ROIDrawingI):

    ##
    # Constructor for LineData object.
    # @param roicoord The ROICoordinate of the object (default: 0,0)
    # @param x1 The first x coordinate of the shape.
    # @param y1 The first y coordinate of the shape.
    # @param x2 The second x  coordinate of the shape.
    # @param y2 The second y coordinate of the shape.

    def __init__(self, roicoord=ROICoordinate(), x1=0, y1=0, x2=0, y2=0):
        warnings.warn(
            "This module is deprecated as of OMERO 5.3.0", DeprecationWarning)
        ShapeData.__init__(self)
        self.x1 = rdouble(x1)
        self.y1 = rdouble(y1)
        self.x2 = rdouble(x2)
        self.y2 = rdouble(y2)
        self.setCoord(roicoord)

    ##
    # overridden, @See ShapeData#setGeometry
    #
    def setGeometry(self, line):
        warnings.warn(
            "This module is deprecated as of OMERO 5.3.0", DeprecationWarning)
        line.setTheZ(self.coord.theZ)
        line.setTheT(self.coord.theT)
        line.setX1(self.x1)
        line.setY1(self.y1)
        line.setX2(self.x2)
        line.setY2(self.y2)

    ##
    # overridden, @See ShapeData#getGeometryFromROI
    #
    def getGeometryFromROI(self, roi):
        warnings.warn(
            "This module is deprecated as of OMERO 5.3.0", DeprecationWarning)
        self.x1 = roi.getX1()
        self.y1 = roi.getY1()
        self.x2 = roi.getX2()
        self.y2 = roi.getY2()

    ##
    # overridden, @See ShapeData#createBaseType
    #
    def createBaseType(self):
        warnings.warn(
            "This module is deprecated as of OMERO 5.3.0", DeprecationWarning)
        return LineI()

    ##
    # overridden, @See ShapeData#acceptVisitor
    #
    def acceptVisitor(self, visitor):
        warnings.warn(
            "This module is deprecated as of OMERO 5.3.0", DeprecationWarning)
        visitor.drawLine(
            self.x1.getValue(), self.y1.getValue(), self.x2.getValue(),
            self.y2.getValue(), self.shapeSettings.getSettings())

##
# The MaskData class contains all the manipulation and create of MaskI
# types.
# It also accepts the ROIDrawingUtils visitor for drawing masks.
#


class MaskData(ShapeData, ROIDrawingI):

    ##
    # Constructor for MaskData object.
    # @param roicoord The ROICoordinate of the object (default: 0,0)
    # @param bytes The mask data.
    # @param x The top left x - coordinate of the shape.
    # @param y The top left y - coordinate of the shape.
    # @param width The width of the shape.
    # @param height The height of the shape.

    def __init__(self, roicoord=ROICoordinate(), bytes=None,
                 x=0, y=0, width=0, height=0):
        warnings.warn(
            "This module is deprecated as of OMERO 5.3.0", DeprecationWarning)
        ShapeData.__init__(self)
        self.x = rdouble(x)
        self.y = rdouble(y)
        self.width = rdouble(width)
        self.height = rdouble(height)
        self.bytesdata = bytes
        self.setCoord(roicoord)

    ##
    # overridden, @See ShapeData#setGeometry
    #
    def setGeometry(self, mask):
        warnings.warn(
            "This module is deprecated as of OMERO 5.3.0", DeprecationWarning)
        mask.setTheZ(self.coord.theZ)
        mask.setTheT(self.coord.theT)
        mask.setX(self.x)
        mask.setY(self.y)
        mask.setWidth(self.width)
        mask.setHeight(self.height)
        mask.setBytes(self.bytedata)

    ##
    # overridden, @See ShapeData#getGeometryFromROI
    #
    def getGeometryFromROI(self, roi):
        warnings.warn(
            "This module is deprecated as of OMERO 5.3.0", DeprecationWarning)
        self.x = roi.getX()
        self.y = roi.getY()
        self.width = roi.getWidth()
        self.height = roi.getHeight()
        self.bytesdata = roi.getBytes()

    ##
    # overridden, @See ShapeData#createBaseType
    #
    def createBaseType(self):
        warnings.warn(
            "This module is deprecated as of OMERO 5.3.0", DeprecationWarning)
        return MaskI()

    ##
    # overridden, @See ShapeData#acceptVisitor
    #
    def acceptVisitor(self, visitor):
        warnings.warn(
            "This module is deprecated as of OMERO 5.3.0", DeprecationWarning)
        visitor.drawMask(
            self.x.getValue(), self.y.getValue(),
            self.width.getValue(), self.height.getValue(),
            self.bytesdata, self.shapeSettings.getSettings())

##
# The PointData class contains all the manipulation and create of PointI
# types.
# It also accepts the ROIDrawingUtils visitor for drawing points.
#


class PointData(ShapeData, ROIDrawingI):

    ##
    # Constructor for PointData object.
    # @param roicoord The ROICoordinate of the object (default: 0,0)
    # @param x The x coordinate of the shape.
    # @param y The y coordinate of the shape.

    def __init__(self, roicoord=ROICoordinate(), x=0, y=0):
        warnings.warn(
            "This module is deprecated as of OMERO 5.3.0", DeprecationWarning)
        ShapeData.__init__(self)
        self.x = rdouble(x)
        self.y = rdouble(y)
        self.setCoord(roicoord)

    ##
    # overridden, @See ShapeData#setGeometry
    #
    def setGeometry(self, point):
        warnings.warn(
            "This module is deprecated as of OMERO 5.3.0", DeprecationWarning)
        point.setTheZ(self.coord.theZ)
        point.setTheT(self.coord.theT)
        point.setX(self.x)
        point.setY(self.y)

    ##
    # overridden, @See ShapeData#getGeometryFromROI
    #
    def getGeometryFromROI(self, roi):
        warnings.warn(
            "This module is deprecated as of OMERO 5.3.0", DeprecationWarning)
        self.x = roi.getX()
        self.y = roi.getY()

    ##
    # overridden, @See ShapeData#createBaseType
    #
    def createBaseType(self):
        warnings.warn(
            "This module is deprecated as of OMERO 5.3.0", DeprecationWarning)
        return PointI()

    ##
    # overridden, @See ShapeData#acceptVisitor
    #
    def acceptVisitor(self, visitor):
        warnings.warn(
            "This module is deprecated as of OMERO 5.3.0", DeprecationWarning)
        visitor.drawEllipse(
            self.x.getValue(), self.y.getValue(), 3, 3,
            self.shapeSettings.getSettings())

##
# The PolygonData class contains all the manipulation and create of PolygonI
# types.
# It also accepts the ROIDrawingUtils visitor for drawing polygons.
#


class PolygonData(ShapeData, ROIDrawingI):

    ##
    # Constructor for PolygonData object.
    # @param roicoord The ROICoordinate of the object (default: 0,0)
    # @param pointList The list of points that make up the polygon,
    #                  as pairs [x1, y1, x2, y2 ..].

    def __init__(self, roicoord=ROICoordinate(), pointsList=(0, 0)):
        warnings.warn(
            "This module is deprecated as of OMERO 5.3.0", DeprecationWarning)
        ShapeData.__init__(self)
        self.points = rstring(self.listToString(pointsList))
        self.setCoord(roicoord)

    ##
    # overridden, @See ShapeData#setGeometry
    #
    def setGeometry(self, polygon):
        warnings.warn(
            "This module is deprecated as of OMERO 5.3.0", DeprecationWarning)
        polygon.setTheZ(self.coord.theZ)
        polygon.setTheT(self.coord.theT)
        polygon.setPoints(self.points)

    ##
    # overridden, @See ShapeData#getGeometryFromROI
    #
    def getGeometryFromROI(self, roi):
        warnings.warn(
            "This module is deprecated as of OMERO 5.3.0", DeprecationWarning)
        self.points = roi.getPoints()

    ##
    # Convert a pointsList[x1,y1,x2,y2..] to a string.
    # @param pointsList The list of points to convert.
    # @return The pointsList converted to a string.
    def listToString(self, pointsList):
        warnings.warn(
            "This module is deprecated as of OMERO 5.3.0", DeprecationWarning)
        string = ''
        cnt = 0
        for element in pointsList:
            if(cnt != 0):
                string = string + ','
            cnt += 1
            string = string + str(element)
        return string

    ##
    # Convert a string of points to a tuple list [(x1,y1),(x2,y2)..].
    # @param pointString The string to convert.
    # @return The tuple list converted from a string.
    def stringToTupleList(self, pointString):
        warnings.warn(
            "This module is deprecated as of OMERO 5.3.0", DeprecationWarning)
        elements = []
        list = pointString.split(',')
        numTokens = len(list)
        for tokenPair in range(0, old_div(numTokens, 2)):
            elements.append(
                (int(list[tokenPair * 2]), int(list[tokenPair * 2 + 1])))
        return elements

    ##
    # overridden, @See ShapeData#createBaseType
    #
    def createBaseType(self):
        warnings.warn(
            "This module is deprecated as of OMERO 5.3.0", DeprecationWarning)
        return PolygonI()

    ##
    # overridden, @See ShapeData#acceptVisitor
    #
    def acceptVisitor(self, visitor):
        warnings.warn(
            "This module is deprecated as of OMERO 5.3.0", DeprecationWarning)
        visitor.drawPolygon(self.stringToTupleList(
            self.points.getValue()), self.shapeSettings.getSettings())

##
# The PolylineData class contains all the manipulation and create of PolylineI
# types.
# It also accepts the ROIDrawingUtils visitor for drawing polylines.
#


class PolylineData(ShapeData, ROIDrawingI):

    ##
    # Constructor for PolylineData object.
    # @param roicoord The ROICoordinate of the object (default: 0,0)
    # @param pointList The list of points that make up the polygon,
    #                  as pairs [x1, y1, x2, y2 ..].

    def __init__(self, roicoord=ROICoordinate(), pointsList=(0, 0)):
        warnings.warn(
            "This module is deprecated as of OMERO 5.3.0", DeprecationWarning)
        ShapeData.__init__(self)
        self.points = rstring(self.listToString(pointsList))
        self.setCoord(roicoord)

    ##
    # overridden, @See ShapeData#setGeometry
    #
    def setGeometry(self, point):
        warnings.warn(
            "This module is deprecated as of OMERO 5.3.0", DeprecationWarning)
        point.setTheZ(self.coord.theZ)
        point.setTheT(self.coord.theT)
        point.setPoints(self.points)

    ##
    # overridden, @See ShapeData#getGeometryFromROI
    #
    def getGeometryFromROI(self, roi):
        warnings.warn(
            "This module is deprecated as of OMERO 5.3.0", DeprecationWarning)
        self.points = roi.getPoints()

    ##
    # Convert a pointsList[x1,y1,x2,y2..] to a string.
    # @param pointsList The list of points to convert.
    # @return The pointsList converted to a string.
    def listToString(self, pointsList):
        warnings.warn(
            "This module is deprecated as of OMERO 5.3.0", DeprecationWarning)
        string = ''
        cnt = 0
        for element in pointsList:
            if(cnt > 0):
                string = string + ','
            string = string + str(element)
            cnt += 1
        return string

    ##
    # Convert a string of points to a tuple list [(x1,y1),(x2,y2)..].
    # @param pointString The string to convert.
    # @return The tuple list converted from a string.
    def stringToTupleList(self, pointString):
        warnings.warn(
            "This module is deprecated as of OMERO 5.3.0", DeprecationWarning)
        elements = []
        list = pointString.split(',')
        numTokens = len(list)
        for tokenPair in range(0, old_div(numTokens, 2)):
            elements.append(
                (int(list[tokenPair * 2]), int(list[tokenPair * 2 + 1])))
        return elements

    ##
    # overridden, @See ShapeData#createBaseType
    #
    def createBaseType(self):
        warnings.warn(
            "This module is deprecated as of OMERO 5.3.0", DeprecationWarning)
        return PolylineI()

    ##
    # overridden, @See ShapeData#acceptVisitor
    #
    def acceptVisitor(self, visitor):
        warnings.warn(
            "This module is deprecated as of OMERO 5.3.0", DeprecationWarning)
        visitor.drawPolyline(self.stringToTupleList(
            self.points.getValue()), self.shapeSettings.getSettings())



# -*- coding: utf-8 -*-
# **********************************************************************
#
# Copyright (c) 2003-2017 ZeroC, Inc. All rights reserved.
#
# This copy of Ice is licensed to you under the terms described in the
# ICE_LICENSE file included in this distribution.
#
# **********************************************************************
#
# Ice version 3.6.4
#
# <auto-generated>
#
# Generated from file `OriginalFile.ice'
#
# Warning: do not edit this file.
#
# </auto-generated>
#

from sys import version_info as _version_info_
import Ice, IcePy
import omero_model_IObject_ice
import omero_RTypes_ice
import omero_model_RTypes_ice
import omero_System_ice
import omero_Collections_ice

# Included module omero
_M_omero = Ice.openModule('omero')

# Included module omero.model
_M_omero.model = Ice.openModule('omero.model')

# Included module Ice
_M_Ice = Ice.openModule('Ice')

# Included module omero.sys
_M_omero.sys = Ice.openModule('omero.sys')

# Included module omero.api
_M_omero.api = Ice.openModule('omero.api')

# Start of module omero
__name__ = 'omero'

# Start of module omero.model
__name__ = 'omero.model'

if 'PixelsOriginalFileMap' not in _M_omero.model.__dict__:
    _M_omero.model._t_PixelsOriginalFileMap = IcePy.declareClass('::omero::model::PixelsOriginalFileMap')
    _M_omero.model._t_PixelsOriginalFileMapPrx = IcePy.declareProxy('::omero::model::PixelsOriginalFileMap')

if 'Pixels' not in _M_omero.model.__dict__:
    _M_omero.model._t_Pixels = IcePy.declareClass('::omero::model::Pixels')
    _M_omero.model._t_PixelsPrx = IcePy.declareProxy('::omero::model::Pixels')

if 'ChecksumAlgorithm' not in _M_omero.model.__dict__:
    _M_omero.model._t_ChecksumAlgorithm = IcePy.declareClass('::omero::model::ChecksumAlgorithm')
    _M_omero.model._t_ChecksumAlgorithmPrx = IcePy.declareProxy('::omero::model::ChecksumAlgorithm')

if 'FilesetEntry' not in _M_omero.model.__dict__:
    _M_omero.model._t_FilesetEntry = IcePy.declareClass('::omero::model::FilesetEntry')
    _M_omero.model._t_FilesetEntryPrx = IcePy.declareProxy('::omero::model::FilesetEntry')

if 'OriginalFileAnnotationLink' not in _M_omero.model.__dict__:
    _M_omero.model._t_OriginalFileAnnotationLink = IcePy.declareClass('::omero::model::OriginalFileAnnotationLink')
    _M_omero.model._t_OriginalFileAnnotationLinkPrx = IcePy.declareProxy('::omero::model::OriginalFileAnnotationLink')

if 'Annotation' not in _M_omero.model.__dict__:
    _M_omero.model._t_Annotation = IcePy.declareClass('::omero::model::Annotation')
    _M_omero.model._t_AnnotationPrx = IcePy.declareProxy('::omero::model::Annotation')

if 'Details' not in _M_omero.model.__dict__:
    _M_omero.model._t_Details = IcePy.declareClass('::omero::model::Details')
    _M_omero.model._t_DetailsPrx = IcePy.declareProxy('::omero::model::Details')

if '_t_OriginalFilePixelsFileMapsSeq' not in _M_omero.model.__dict__:
    _M_omero.model._t_OriginalFilePixelsFileMapsSeq = IcePy.defineSequence('::omero::model::OriginalFilePixelsFileMapsSeq', (), _M_omero.model._t_PixelsOriginalFileMap)

if '_t_OriginalFileLinkedPixelsSeq' not in _M_omero.model.__dict__:
    _M_omero.model._t_OriginalFileLinkedPixelsSeq = IcePy.defineSequence('::omero::model::OriginalFileLinkedPixelsSeq', (), _M_omero.model._t_Pixels)

if '_t_OriginalFileFilesetEntriesSeq' not in _M_omero.model.__dict__:
    _M_omero.model._t_OriginalFileFilesetEntriesSeq = IcePy.defineSequence('::omero::model::OriginalFileFilesetEntriesSeq', (), _M_omero.model._t_FilesetEntry)

if '_t_OriginalFileAnnotationLinksSeq' not in _M_omero.model.__dict__:
    _M_omero.model._t_OriginalFileAnnotationLinksSeq = IcePy.defineSequence('::omero::model::OriginalFileAnnotationLinksSeq', (), _M_omero.model._t_OriginalFileAnnotationLink)

if '_t_OriginalFileLinkedAnnotationSeq' not in _M_omero.model.__dict__:
    _M_omero.model._t_OriginalFileLinkedAnnotationSeq = IcePy.defineSequence('::omero::model::OriginalFileLinkedAnnotationSeq', (), _M_omero.model._t_Annotation)

if 'OriginalFile' not in _M_omero.model.__dict__:
    _M_omero.model.OriginalFile = Ice.createTempClass()
    class OriginalFile(_M_omero.model.IObject):
        def __init__(self, _id=None, _details=None, _loaded=False, _version=None, _pixelsFileMapsSeq=None, _pixelsFileMapsLoaded=False, _pixelsFileMapsCountPerOwner=None, _path=None, _repo=None, _size=None, _atime=None, _mtime=None, _ctime=None, _hasher=None, _hash=None, _mimetype=None, _filesetEntriesSeq=None, _filesetEntriesLoaded=False, _annotationLinksSeq=None, _annotationLinksLoaded=False, _annotationLinksCountPerOwner=None, _name=None):
            if Ice.getType(self) == _M_omero.model.OriginalFile:
                raise RuntimeError('omero.model.OriginalFile is an abstract class')
            _M_omero.model.IObject.__init__(self, _id, _details, _loaded)
            self._version = _version
            self._pixelsFileMapsSeq = _pixelsFileMapsSeq
            self._pixelsFileMapsLoaded = _pixelsFileMapsLoaded
            self._pixelsFileMapsCountPerOwner = _pixelsFileMapsCountPerOwner
            self._path = _path
            self._repo = _repo
            self._size = _size
            self._atime = _atime
            self._mtime = _mtime
            self._ctime = _ctime
            self._hasher = _hasher
            self._hash = _hash
            self._mimetype = _mimetype
            self._filesetEntriesSeq = _filesetEntriesSeq
            self._filesetEntriesLoaded = _filesetEntriesLoaded
            self._annotationLinksSeq = _annotationLinksSeq
            self._annotationLinksLoaded = _annotationLinksLoaded
            self._annotationLinksCountPerOwner = _annotationLinksCountPerOwner
            self._name = _name

        def ice_ids(self, current=None):
            return ('::Ice::Object', '::omero::model::IObject', '::omero::model::OriginalFile')

        def ice_id(self, current=None):
            return '::omero::model::OriginalFile'

        def ice_staticId():
            return '::omero::model::OriginalFile'
        ice_staticId = staticmethod(ice_staticId)

        def getVersion(self, current=None):
            pass

        def setVersion(self, theVersion, current=None):
            pass

        def unloadPixelsFileMaps(self, current=None):
            pass

        def sizeOfPixelsFileMaps(self, current=None):
            pass

        def copyPixelsFileMaps(self, current=None):
            pass

        def addPixelsOriginalFileMap(self, target, current=None):
            pass

        def addAllPixelsOriginalFileMapSet(self, targets, current=None):
            pass

        def removePixelsOriginalFileMap(self, theTarget, current=None):
            pass

        def removeAllPixelsOriginalFileMapSet(self, targets, current=None):
            pass

        def clearPixelsFileMaps(self, current=None):
            pass

        def reloadPixelsFileMaps(self, toCopy, current=None):
            pass

        def getPixelsFileMapsCountPerOwner(self, current=None):
            pass

        def linkPixels(self, addition, current=None):
            pass

        def addPixelsOriginalFileMapToBoth(self, link, bothSides, current=None):
            pass

        def findPixelsOriginalFileMap(self, removal, current=None):
            pass

        def unlinkPixels(self, removal, current=None):
            pass

        def removePixelsOriginalFileMapFromBoth(self, link, bothSides, current=None):
            pass

        def linkedPixelsList(self, current=None):
            pass

        def getPath(self, current=None):
            pass

        def setPath(self, thePath, current=None):
            pass

        def getRepo(self, current=None):
            pass

        def setRepo(self, theRepo, current=None):
            pass

        def getSize(self, current=None):
            pass

        def setSize(self, theSize, current=None):
            pass

        def getAtime(self, current=None):
            pass

        def setAtime(self, theAtime, current=None):
            pass

        def getMtime(self, current=None):
            pass

        def setMtime(self, theMtime, current=None):
            pass

        def getCtime(self, current=None):
            pass

        def setCtime(self, theCtime, current=None):
            pass

        def getHasher(self, current=None):
            pass

        def setHasher(self, theHasher, current=None):
            pass

        def getHash(self, current=None):
            pass

        def setHash(self, theHash, current=None):
            pass

        def getMimetype(self, current=None):
            pass

        def setMimetype(self, theMimetype, current=None):
            pass

        def unloadFilesetEntries(self, current=None):
            pass

        def sizeOfFilesetEntries(self, current=None):
            pass

        def copyFilesetEntries(self, current=None):
            pass

        def addFilesetEntry(self, target, current=None):
            pass

        def addAllFilesetEntrySet(self, targets, current=None):
            pass

        def removeFilesetEntry(self, theTarget, current=None):
            pass

        def removeAllFilesetEntrySet(self, targets, current=None):
            pass

        def clearFilesetEntries(self, current=None):
            pass

        def reloadFilesetEntries(self, toCopy, current=None):
            pass

        def unloadAnnotationLinks(self, current=None):
            pass

        def sizeOfAnnotationLinks(self, current=None):
            pass

        def copyAnnotationLinks(self, current=None):
            pass

        def addOriginalFileAnnotationLink(self, target, current=None):
            pass

        def addAllOriginalFileAnnotationLinkSet(self, targets, current=None):
            pass

        def removeOriginalFileAnnotationLink(self, theTarget, current=None):
            pass

        def removeAllOriginalFileAnnotationLinkSet(self, targets, current=None):
            pass

        def clearAnnotationLinks(self, current=None):
            pass

        def reloadAnnotationLinks(self, toCopy, current=None):
            pass

        def getAnnotationLinksCountPerOwner(self, current=None):
            pass

        def linkAnnotation(self, addition, current=None):
            pass

        def addOriginalFileAnnotationLinkToBoth(self, link, bothSides, current=None):
            pass

        def findOriginalFileAnnotationLink(self, removal, current=None):
            pass

        def unlinkAnnotation(self, removal, current=None):
            pass

        def removeOriginalFileAnnotationLinkFromBoth(self, link, bothSides, current=None):
            pass

        def linkedAnnotationList(self, current=None):
            pass

        def getName(self, current=None):
            pass

        def setName(self, theName, current=None):
            pass

        def __str__(self):
            return IcePy.stringify(self, _M_omero.model._t_OriginalFile)

        __repr__ = __str__

    _M_omero.model.OriginalFilePrx = Ice.createTempClass()
    class OriginalFilePrx(_M_omero.model.IObjectPrx):

        def getVersion(self, _ctx=None):
            return _M_omero.model.OriginalFile._op_getVersion.invoke(self, ((), _ctx))

        def begin_getVersion(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.OriginalFile._op_getVersion.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getVersion(self, _r):
            return _M_omero.model.OriginalFile._op_getVersion.end(self, _r)

        def setVersion(self, theVersion, _ctx=None):
            return _M_omero.model.OriginalFile._op_setVersion.invoke(self, ((theVersion, ), _ctx))

        def begin_setVersion(self, theVersion, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.OriginalFile._op_setVersion.begin(self, ((theVersion, ), _response, _ex, _sent, _ctx))

        def end_setVersion(self, _r):
            return _M_omero.model.OriginalFile._op_setVersion.end(self, _r)

        def unloadPixelsFileMaps(self, _ctx=None):
            return _M_omero.model.OriginalFile._op_unloadPixelsFileMaps.invoke(self, ((), _ctx))

        def begin_unloadPixelsFileMaps(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.OriginalFile._op_unloadPixelsFileMaps.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_unloadPixelsFileMaps(self, _r):
            return _M_omero.model.OriginalFile._op_unloadPixelsFileMaps.end(self, _r)

        def sizeOfPixelsFileMaps(self, _ctx=None):
            return _M_omero.model.OriginalFile._op_sizeOfPixelsFileMaps.invoke(self, ((), _ctx))

        def begin_sizeOfPixelsFileMaps(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.OriginalFile._op_sizeOfPixelsFileMaps.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_sizeOfPixelsFileMaps(self, _r):
            return _M_omero.model.OriginalFile._op_sizeOfPixelsFileMaps.end(self, _r)

        def copyPixelsFileMaps(self, _ctx=None):
            return _M_omero.model.OriginalFile._op_copyPixelsFileMaps.invoke(self, ((), _ctx))

        def begin_copyPixelsFileMaps(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.OriginalFile._op_copyPixelsFileMaps.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_copyPixelsFileMaps(self, _r):
            return _M_omero.model.OriginalFile._op_copyPixelsFileMaps.end(self, _r)

        def addPixelsOriginalFileMap(self, target, _ctx=None):
            return _M_omero.model.OriginalFile._op_addPixelsOriginalFileMap.invoke(self, ((target, ), _ctx))

        def begin_addPixelsOriginalFileMap(self, target, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.OriginalFile._op_addPixelsOriginalFileMap.begin(self, ((target, ), _response, _ex, _sent, _ctx))

        def end_addPixelsOriginalFileMap(self, _r):
            return _M_omero.model.OriginalFile._op_addPixelsOriginalFileMap.end(self, _r)

        def addAllPixelsOriginalFileMapSet(self, targets, _ctx=None):
            return _M_omero.model.OriginalFile._op_addAllPixelsOriginalFileMapSet.invoke(self, ((targets, ), _ctx))

        def begin_addAllPixelsOriginalFileMapSet(self, targets, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.OriginalFile._op_addAllPixelsOriginalFileMapSet.begin(self, ((targets, ), _response, _ex, _sent, _ctx))

        def end_addAllPixelsOriginalFileMapSet(self, _r):
            return _M_omero.model.OriginalFile._op_addAllPixelsOriginalFileMapSet.end(self, _r)

        def removePixelsOriginalFileMap(self, theTarget, _ctx=None):
            return _M_omero.model.OriginalFile._op_removePixelsOriginalFileMap.invoke(self, ((theTarget, ), _ctx))

        def begin_removePixelsOriginalFileMap(self, theTarget, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.OriginalFile._op_removePixelsOriginalFileMap.begin(self, ((theTarget, ), _response, _ex, _sent, _ctx))

        def end_removePixelsOriginalFileMap(self, _r):
            return _M_omero.model.OriginalFile._op_removePixelsOriginalFileMap.end(self, _r)

        def removeAllPixelsOriginalFileMapSet(self, targets, _ctx=None):
            return _M_omero.model.OriginalFile._op_removeAllPixelsOriginalFileMapSet.invoke(self, ((targets, ), _ctx))

        def begin_removeAllPixelsOriginalFileMapSet(self, targets, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.OriginalFile._op_removeAllPixelsOriginalFileMapSet.begin(self, ((targets, ), _response, _ex, _sent, _ctx))

        def end_removeAllPixelsOriginalFileMapSet(self, _r):
            return _M_omero.model.OriginalFile._op_removeAllPixelsOriginalFileMapSet.end(self, _r)

        def clearPixelsFileMaps(self, _ctx=None):
            return _M_omero.model.OriginalFile._op_clearPixelsFileMaps.invoke(self, ((), _ctx))

        def begin_clearPixelsFileMaps(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.OriginalFile._op_clearPixelsFileMaps.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_clearPixelsFileMaps(self, _r):
            return _M_omero.model.OriginalFile._op_clearPixelsFileMaps.end(self, _r)

        def reloadPixelsFileMaps(self, toCopy, _ctx=None):
            return _M_omero.model.OriginalFile._op_reloadPixelsFileMaps.invoke(self, ((toCopy, ), _ctx))

        def begin_reloadPixelsFileMaps(self, toCopy, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.OriginalFile._op_reloadPixelsFileMaps.begin(self, ((toCopy, ), _response, _ex, _sent, _ctx))

        def end_reloadPixelsFileMaps(self, _r):
            return _M_omero.model.OriginalFile._op_reloadPixelsFileMaps.end(self, _r)

        def getPixelsFileMapsCountPerOwner(self, _ctx=None):
            return _M_omero.model.OriginalFile._op_getPixelsFileMapsCountPerOwner.invoke(self, ((), _ctx))

        def begin_getPixelsFileMapsCountPerOwner(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.OriginalFile._op_getPixelsFileMapsCountPerOwner.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getPixelsFileMapsCountPerOwner(self, _r):
            return _M_omero.model.OriginalFile._op_getPixelsFileMapsCountPerOwner.end(self, _r)

        def linkPixels(self, addition, _ctx=None):
            return _M_omero.model.OriginalFile._op_linkPixels.invoke(self, ((addition, ), _ctx))

        def begin_linkPixels(self, addition, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.OriginalFile._op_linkPixels.begin(self, ((addition, ), _response, _ex, _sent, _ctx))

        def end_linkPixels(self, _r):
            return _M_omero.model.OriginalFile._op_linkPixels.end(self, _r)

        def addPixelsOriginalFileMapToBoth(self, link, bothSides, _ctx=None):
            return _M_omero.model.OriginalFile._op_addPixelsOriginalFileMapToBoth.invoke(self, ((link, bothSides), _ctx))

        def begin_addPixelsOriginalFileMapToBoth(self, link, bothSides, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.OriginalFile._op_addPixelsOriginalFileMapToBoth.begin(self, ((link, bothSides), _response, _ex, _sent, _ctx))

        def end_addPixelsOriginalFileMapToBoth(self, _r):
            return _M_omero.model.OriginalFile._op_addPixelsOriginalFileMapToBoth.end(self, _r)

        def findPixelsOriginalFileMap(self, removal, _ctx=None):
            return _M_omero.model.OriginalFile._op_findPixelsOriginalFileMap.invoke(self, ((removal, ), _ctx))

        def begin_findPixelsOriginalFileMap(self, removal, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.OriginalFile._op_findPixelsOriginalFileMap.begin(self, ((removal, ), _response, _ex, _sent, _ctx))

        def end_findPixelsOriginalFileMap(self, _r):
            return _M_omero.model.OriginalFile._op_findPixelsOriginalFileMap.end(self, _r)

        def unlinkPixels(self, removal, _ctx=None):
            return _M_omero.model.OriginalFile._op_unlinkPixels.invoke(self, ((removal, ), _ctx))

        def begin_unlinkPixels(self, removal, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.OriginalFile._op_unlinkPixels.begin(self, ((removal, ), _response, _ex, _sent, _ctx))

        def end_unlinkPixels(self, _r):
            return _M_omero.model.OriginalFile._op_unlinkPixels.end(self, _r)

        def removePixelsOriginalFileMapFromBoth(self, link, bothSides, _ctx=None):
            return _M_omero.model.OriginalFile._op_removePixelsOriginalFileMapFromBoth.invoke(self, ((link, bothSides), _ctx))

        def begin_removePixelsOriginalFileMapFromBoth(self, link, bothSides, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.OriginalFile._op_removePixelsOriginalFileMapFromBoth.begin(self, ((link, bothSides), _response, _ex, _sent, _ctx))

        def end_removePixelsOriginalFileMapFromBoth(self, _r):
            return _M_omero.model.OriginalFile._op_removePixelsOriginalFileMapFromBoth.end(self, _r)

        def linkedPixelsList(self, _ctx=None):
            return _M_omero.model.OriginalFile._op_linkedPixelsList.invoke(self, ((), _ctx))

        def begin_linkedPixelsList(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.OriginalFile._op_linkedPixelsList.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_linkedPixelsList(self, _r):
            return _M_omero.model.OriginalFile._op_linkedPixelsList.end(self, _r)

        def getPath(self, _ctx=None):
            return _M_omero.model.OriginalFile._op_getPath.invoke(self, ((), _ctx))

        def begin_getPath(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.OriginalFile._op_getPath.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getPath(self, _r):
            return _M_omero.model.OriginalFile._op_getPath.end(self, _r)

        def setPath(self, thePath, _ctx=None):
            return _M_omero.model.OriginalFile._op_setPath.invoke(self, ((thePath, ), _ctx))

        def begin_setPath(self, thePath, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.OriginalFile._op_setPath.begin(self, ((thePath, ), _response, _ex, _sent, _ctx))

        def end_setPath(self, _r):
            return _M_omero.model.OriginalFile._op_setPath.end(self, _r)

        def getRepo(self, _ctx=None):
            return _M_omero.model.OriginalFile._op_getRepo.invoke(self, ((), _ctx))

        def begin_getRepo(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.OriginalFile._op_getRepo.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getRepo(self, _r):
            return _M_omero.model.OriginalFile._op_getRepo.end(self, _r)

        def setRepo(self, theRepo, _ctx=None):
            return _M_omero.model.OriginalFile._op_setRepo.invoke(self, ((theRepo, ), _ctx))

        def begin_setRepo(self, theRepo, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.OriginalFile._op_setRepo.begin(self, ((theRepo, ), _response, _ex, _sent, _ctx))

        def end_setRepo(self, _r):
            return _M_omero.model.OriginalFile._op_setRepo.end(self, _r)

        def getSize(self, _ctx=None):
            return _M_omero.model.OriginalFile._op_getSize.invoke(self, ((), _ctx))

        def begin_getSize(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.OriginalFile._op_getSize.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getSize(self, _r):
            return _M_omero.model.OriginalFile._op_getSize.end(self, _r)

        def setSize(self, theSize, _ctx=None):
            return _M_omero.model.OriginalFile._op_setSize.invoke(self, ((theSize, ), _ctx))

        def begin_setSize(self, theSize, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.OriginalFile._op_setSize.begin(self, ((theSize, ), _response, _ex, _sent, _ctx))

        def end_setSize(self, _r):
            return _M_omero.model.OriginalFile._op_setSize.end(self, _r)

        def getAtime(self, _ctx=None):
            return _M_omero.model.OriginalFile._op_getAtime.invoke(self, ((), _ctx))

        def begin_getAtime(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.OriginalFile._op_getAtime.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getAtime(self, _r):
            return _M_omero.model.OriginalFile._op_getAtime.end(self, _r)

        def setAtime(self, theAtime, _ctx=None):
            return _M_omero.model.OriginalFile._op_setAtime.invoke(self, ((theAtime, ), _ctx))

        def begin_setAtime(self, theAtime, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.OriginalFile._op_setAtime.begin(self, ((theAtime, ), _response, _ex, _sent, _ctx))

        def end_setAtime(self, _r):
            return _M_omero.model.OriginalFile._op_setAtime.end(self, _r)

        def getMtime(self, _ctx=None):
            return _M_omero.model.OriginalFile._op_getMtime.invoke(self, ((), _ctx))

        def begin_getMtime(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.OriginalFile._op_getMtime.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getMtime(self, _r):
            return _M_omero.model.OriginalFile._op_getMtime.end(self, _r)

        def setMtime(self, theMtime, _ctx=None):
            return _M_omero.model.OriginalFile._op_setMtime.invoke(self, ((theMtime, ), _ctx))

        def begin_setMtime(self, theMtime, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.OriginalFile._op_setMtime.begin(self, ((theMtime, ), _response, _ex, _sent, _ctx))

        def end_setMtime(self, _r):
            return _M_omero.model.OriginalFile._op_setMtime.end(self, _r)

        def getCtime(self, _ctx=None):
            return _M_omero.model.OriginalFile._op_getCtime.invoke(self, ((), _ctx))

        def begin_getCtime(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.OriginalFile._op_getCtime.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getCtime(self, _r):
            return _M_omero.model.OriginalFile._op_getCtime.end(self, _r)

        def setCtime(self, theCtime, _ctx=None):
            return _M_omero.model.OriginalFile._op_setCtime.invoke(self, ((theCtime, ), _ctx))

        def begin_setCtime(self, theCtime, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.OriginalFile._op_setCtime.begin(self, ((theCtime, ), _response, _ex, _sent, _ctx))

        def end_setCtime(self, _r):
            return _M_omero.model.OriginalFile._op_setCtime.end(self, _r)

        def getHasher(self, _ctx=None):
            return _M_omero.model.OriginalFile._op_getHasher.invoke(self, ((), _ctx))

        def begin_getHasher(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.OriginalFile._op_getHasher.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getHasher(self, _r):
            return _M_omero.model.OriginalFile._op_getHasher.end(self, _r)

        def setHasher(self, theHasher, _ctx=None):
            return _M_omero.model.OriginalFile._op_setHasher.invoke(self, ((theHasher, ), _ctx))

        def begin_setHasher(self, theHasher, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.OriginalFile._op_setHasher.begin(self, ((theHasher, ), _response, _ex, _sent, _ctx))

        def end_setHasher(self, _r):
            return _M_omero.model.OriginalFile._op_setHasher.end(self, _r)

        def getHash(self, _ctx=None):
            return _M_omero.model.OriginalFile._op_getHash.invoke(self, ((), _ctx))

        def begin_getHash(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.OriginalFile._op_getHash.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getHash(self, _r):
            return _M_omero.model.OriginalFile._op_getHash.end(self, _r)

        def setHash(self, theHash, _ctx=None):
            return _M_omero.model.OriginalFile._op_setHash.invoke(self, ((theHash, ), _ctx))

        def begin_setHash(self, theHash, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.OriginalFile._op_setHash.begin(self, ((theHash, ), _response, _ex, _sent, _ctx))

        def end_setHash(self, _r):
            return _M_omero.model.OriginalFile._op_setHash.end(self, _r)

        def getMimetype(self, _ctx=None):
            return _M_omero.model.OriginalFile._op_getMimetype.invoke(self, ((), _ctx))

        def begin_getMimetype(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.OriginalFile._op_getMimetype.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getMimetype(self, _r):
            return _M_omero.model.OriginalFile._op_getMimetype.end(self, _r)

        def setMimetype(self, theMimetype, _ctx=None):
            return _M_omero.model.OriginalFile._op_setMimetype.invoke(self, ((theMimetype, ), _ctx))

        def begin_setMimetype(self, theMimetype, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.OriginalFile._op_setMimetype.begin(self, ((theMimetype, ), _response, _ex, _sent, _ctx))

        def end_setMimetype(self, _r):
            return _M_omero.model.OriginalFile._op_setMimetype.end(self, _r)

        def unloadFilesetEntries(self, _ctx=None):
            return _M_omero.model.OriginalFile._op_unloadFilesetEntries.invoke(self, ((), _ctx))

        def begin_unloadFilesetEntries(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.OriginalFile._op_unloadFilesetEntries.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_unloadFilesetEntries(self, _r):
            return _M_omero.model.OriginalFile._op_unloadFilesetEntries.end(self, _r)

        def sizeOfFilesetEntries(self, _ctx=None):
            return _M_omero.model.OriginalFile._op_sizeOfFilesetEntries.invoke(self, ((), _ctx))

        def begin_sizeOfFilesetEntries(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.OriginalFile._op_sizeOfFilesetEntries.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_sizeOfFilesetEntries(self, _r):
            return _M_omero.model.OriginalFile._op_sizeOfFilesetEntries.end(self, _r)

        def copyFilesetEntries(self, _ctx=None):
            return _M_omero.model.OriginalFile._op_copyFilesetEntries.invoke(self, ((), _ctx))

        def begin_copyFilesetEntries(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.OriginalFile._op_copyFilesetEntries.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_copyFilesetEntries(self, _r):
            return _M_omero.model.OriginalFile._op_copyFilesetEntries.end(self, _r)

        def addFilesetEntry(self, target, _ctx=None):
            return _M_omero.model.OriginalFile._op_addFilesetEntry.invoke(self, ((target, ), _ctx))

        def begin_addFilesetEntry(self, target, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.OriginalFile._op_addFilesetEntry.begin(self, ((target, ), _response, _ex, _sent, _ctx))

        def end_addFilesetEntry(self, _r):
            return _M_omero.model.OriginalFile._op_addFilesetEntry.end(self, _r)

        def addAllFilesetEntrySet(self, targets, _ctx=None):
            return _M_omero.model.OriginalFile._op_addAllFilesetEntrySet.invoke(self, ((targets, ), _ctx))

        def begin_addAllFilesetEntrySet(self, targets, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.OriginalFile._op_addAllFilesetEntrySet.begin(self, ((targets, ), _response, _ex, _sent, _ctx))

        def end_addAllFilesetEntrySet(self, _r):
            return _M_omero.model.OriginalFile._op_addAllFilesetEntrySet.end(self, _r)

        def removeFilesetEntry(self, theTarget, _ctx=None):
            return _M_omero.model.OriginalFile._op_removeFilesetEntry.invoke(self, ((theTarget, ), _ctx))

        def begin_removeFilesetEntry(self, theTarget, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.OriginalFile._op_removeFilesetEntry.begin(self, ((theTarget, ), _response, _ex, _sent, _ctx))

        def end_removeFilesetEntry(self, _r):
            return _M_omero.model.OriginalFile._op_removeFilesetEntry.end(self, _r)

        def removeAllFilesetEntrySet(self, targets, _ctx=None):
            return _M_omero.model.OriginalFile._op_removeAllFilesetEntrySet.invoke(self, ((targets, ), _ctx))

        def begin_removeAllFilesetEntrySet(self, targets, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.OriginalFile._op_removeAllFilesetEntrySet.begin(self, ((targets, ), _response, _ex, _sent, _ctx))

        def end_removeAllFilesetEntrySet(self, _r):
            return _M_omero.model.OriginalFile._op_removeAllFilesetEntrySet.end(self, _r)

        def clearFilesetEntries(self, _ctx=None):
            return _M_omero.model.OriginalFile._op_clearFilesetEntries.invoke(self, ((), _ctx))

        def begin_clearFilesetEntries(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.OriginalFile._op_clearFilesetEntries.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_clearFilesetEntries(self, _r):
            return _M_omero.model.OriginalFile._op_clearFilesetEntries.end(self, _r)

        def reloadFilesetEntries(self, toCopy, _ctx=None):
            return _M_omero.model.OriginalFile._op_reloadFilesetEntries.invoke(self, ((toCopy, ), _ctx))

        def begin_reloadFilesetEntries(self, toCopy, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.OriginalFile._op_reloadFilesetEntries.begin(self, ((toCopy, ), _response, _ex, _sent, _ctx))

        def end_reloadFilesetEntries(self, _r):
            return _M_omero.model.OriginalFile._op_reloadFilesetEntries.end(self, _r)

        def unloadAnnotationLinks(self, _ctx=None):
            return _M_omero.model.OriginalFile._op_unloadAnnotationLinks.invoke(self, ((), _ctx))

        def begin_unloadAnnotationLinks(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.OriginalFile._op_unloadAnnotationLinks.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_unloadAnnotationLinks(self, _r):
            return _M_omero.model.OriginalFile._op_unloadAnnotationLinks.end(self, _r)

        def sizeOfAnnotationLinks(self, _ctx=None):
            return _M_omero.model.OriginalFile._op_sizeOfAnnotationLinks.invoke(self, ((), _ctx))

        def begin_sizeOfAnnotationLinks(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.OriginalFile._op_sizeOfAnnotationLinks.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_sizeOfAnnotationLinks(self, _r):
            return _M_omero.model.OriginalFile._op_sizeOfAnnotationLinks.end(self, _r)

        def copyAnnotationLinks(self, _ctx=None):
            return _M_omero.model.OriginalFile._op_copyAnnotationLinks.invoke(self, ((), _ctx))

        def begin_copyAnnotationLinks(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.OriginalFile._op_copyAnnotationLinks.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_copyAnnotationLinks(self, _r):
            return _M_omero.model.OriginalFile._op_copyAnnotationLinks.end(self, _r)

        def addOriginalFileAnnotationLink(self, target, _ctx=None):
            return _M_omero.model.OriginalFile._op_addOriginalFileAnnotationLink.invoke(self, ((target, ), _ctx))

        def begin_addOriginalFileAnnotationLink(self, target, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.OriginalFile._op_addOriginalFileAnnotationLink.begin(self, ((target, ), _response, _ex, _sent, _ctx))

        def end_addOriginalFileAnnotationLink(self, _r):
            return _M_omero.model.OriginalFile._op_addOriginalFileAnnotationLink.end(self, _r)

        def addAllOriginalFileAnnotationLinkSet(self, targets, _ctx=None):
            return _M_omero.model.OriginalFile._op_addAllOriginalFileAnnotationLinkSet.invoke(self, ((targets, ), _ctx))

        def begin_addAllOriginalFileAnnotationLinkSet(self, targets, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.OriginalFile._op_addAllOriginalFileAnnotationLinkSet.begin(self, ((targets, ), _response, _ex, _sent, _ctx))

        def end_addAllOriginalFileAnnotationLinkSet(self, _r):
            return _M_omero.model.OriginalFile._op_addAllOriginalFileAnnotationLinkSet.end(self, _r)

        def removeOriginalFileAnnotationLink(self, theTarget, _ctx=None):
            return _M_omero.model.OriginalFile._op_removeOriginalFileAnnotationLink.invoke(self, ((theTarget, ), _ctx))

        def begin_removeOriginalFileAnnotationLink(self, theTarget, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.OriginalFile._op_removeOriginalFileAnnotationLink.begin(self, ((theTarget, ), _response, _ex, _sent, _ctx))

        def end_removeOriginalFileAnnotationLink(self, _r):
            return _M_omero.model.OriginalFile._op_removeOriginalFileAnnotationLink.end(self, _r)

        def removeAllOriginalFileAnnotationLinkSet(self, targets, _ctx=None):
            return _M_omero.model.OriginalFile._op_removeAllOriginalFileAnnotationLinkSet.invoke(self, ((targets, ), _ctx))

        def begin_removeAllOriginalFileAnnotationLinkSet(self, targets, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.OriginalFile._op_removeAllOriginalFileAnnotationLinkSet.begin(self, ((targets, ), _response, _ex, _sent, _ctx))

        def end_removeAllOriginalFileAnnotationLinkSet(self, _r):
            return _M_omero.model.OriginalFile._op_removeAllOriginalFileAnnotationLinkSet.end(self, _r)

        def clearAnnotationLinks(self, _ctx=None):
            return _M_omero.model.OriginalFile._op_clearAnnotationLinks.invoke(self, ((), _ctx))

        def begin_clearAnnotationLinks(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.OriginalFile._op_clearAnnotationLinks.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_clearAnnotationLinks(self, _r):
            return _M_omero.model.OriginalFile._op_clearAnnotationLinks.end(self, _r)

        def reloadAnnotationLinks(self, toCopy, _ctx=None):
            return _M_omero.model.OriginalFile._op_reloadAnnotationLinks.invoke(self, ((toCopy, ), _ctx))

        def begin_reloadAnnotationLinks(self, toCopy, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.OriginalFile._op_reloadAnnotationLinks.begin(self, ((toCopy, ), _response, _ex, _sent, _ctx))

        def end_reloadAnnotationLinks(self, _r):
            return _M_omero.model.OriginalFile._op_reloadAnnotationLinks.end(self, _r)

        def getAnnotationLinksCountPerOwner(self, _ctx=None):
            return _M_omero.model.OriginalFile._op_getAnnotationLinksCountPerOwner.invoke(self, ((), _ctx))

        def begin_getAnnotationLinksCountPerOwner(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.OriginalFile._op_getAnnotationLinksCountPerOwner.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getAnnotationLinksCountPerOwner(self, _r):
            return _M_omero.model.OriginalFile._op_getAnnotationLinksCountPerOwner.end(self, _r)

        def linkAnnotation(self, addition, _ctx=None):
            return _M_omero.model.OriginalFile._op_linkAnnotation.invoke(self, ((addition, ), _ctx))

        def begin_linkAnnotation(self, addition, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.OriginalFile._op_linkAnnotation.begin(self, ((addition, ), _response, _ex, _sent, _ctx))

        def end_linkAnnotation(self, _r):
            return _M_omero.model.OriginalFile._op_linkAnnotation.end(self, _r)

        def addOriginalFileAnnotationLinkToBoth(self, link, bothSides, _ctx=None):
            return _M_omero.model.OriginalFile._op_addOriginalFileAnnotationLinkToBoth.invoke(self, ((link, bothSides), _ctx))

        def begin_addOriginalFileAnnotationLinkToBoth(self, link, bothSides, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.OriginalFile._op_addOriginalFileAnnotationLinkToBoth.begin(self, ((link, bothSides), _response, _ex, _sent, _ctx))

        def end_addOriginalFileAnnotationLinkToBoth(self, _r):
            return _M_omero.model.OriginalFile._op_addOriginalFileAnnotationLinkToBoth.end(self, _r)

        def findOriginalFileAnnotationLink(self, removal, _ctx=None):
            return _M_omero.model.OriginalFile._op_findOriginalFileAnnotationLink.invoke(self, ((removal, ), _ctx))

        def begin_findOriginalFileAnnotationLink(self, removal, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.OriginalFile._op_findOriginalFileAnnotationLink.begin(self, ((removal, ), _response, _ex, _sent, _ctx))

        def end_findOriginalFileAnnotationLink(self, _r):
            return _M_omero.model.OriginalFile._op_findOriginalFileAnnotationLink.end(self, _r)

        def unlinkAnnotation(self, removal, _ctx=None):
            return _M_omero.model.OriginalFile._op_unlinkAnnotation.invoke(self, ((removal, ), _ctx))

        def begin_unlinkAnnotation(self, removal, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.OriginalFile._op_unlinkAnnotation.begin(self, ((removal, ), _response, _ex, _sent, _ctx))

        def end_unlinkAnnotation(self, _r):
            return _M_omero.model.OriginalFile._op_unlinkAnnotation.end(self, _r)

        def removeOriginalFileAnnotationLinkFromBoth(self, link, bothSides, _ctx=None):
            return _M_omero.model.OriginalFile._op_removeOriginalFileAnnotationLinkFromBoth.invoke(self, ((link, bothSides), _ctx))

        def begin_removeOriginalFileAnnotationLinkFromBoth(self, link, bothSides, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.OriginalFile._op_removeOriginalFileAnnotationLinkFromBoth.begin(self, ((link, bothSides), _response, _ex, _sent, _ctx))

        def end_removeOriginalFileAnnotationLinkFromBoth(self, _r):
            return _M_omero.model.OriginalFile._op_removeOriginalFileAnnotationLinkFromBoth.end(self, _r)

        def linkedAnnotationList(self, _ctx=None):
            return _M_omero.model.OriginalFile._op_linkedAnnotationList.invoke(self, ((), _ctx))

        def begin_linkedAnnotationList(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.OriginalFile._op_linkedAnnotationList.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_linkedAnnotationList(self, _r):
            return _M_omero.model.OriginalFile._op_linkedAnnotationList.end(self, _r)

        def getName(self, _ctx=None):
            return _M_omero.model.OriginalFile._op_getName.invoke(self, ((), _ctx))

        def begin_getName(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.OriginalFile._op_getName.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getName(self, _r):
            return _M_omero.model.OriginalFile._op_getName.end(self, _r)

        def setName(self, theName, _ctx=None):
            return _M_omero.model.OriginalFile._op_setName.invoke(self, ((theName, ), _ctx))

        def begin_setName(self, theName, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.OriginalFile._op_setName.begin(self, ((theName, ), _response, _ex, _sent, _ctx))

        def end_setName(self, _r):
            return _M_omero.model.OriginalFile._op_setName.end(self, _r)

        def checkedCast(proxy, facetOrCtx=None, _ctx=None):
            return _M_omero.model.OriginalFilePrx.ice_checkedCast(proxy, '::omero::model::OriginalFile', facetOrCtx, _ctx)
        checkedCast = staticmethod(checkedCast)

        def uncheckedCast(proxy, facet=None):
            return _M_omero.model.OriginalFilePrx.ice_uncheckedCast(proxy, facet)
        uncheckedCast = staticmethod(uncheckedCast)

        def ice_staticId():
            return '::omero::model::OriginalFile'
        ice_staticId = staticmethod(ice_staticId)

    _M_omero.model._t_OriginalFilePrx = IcePy.defineProxy('::omero::model::OriginalFile', OriginalFilePrx)

    _M_omero.model._t_OriginalFile = IcePy.declareClass('::omero::model::OriginalFile')

    _M_omero.model._t_OriginalFile = IcePy.defineClass('::omero::model::OriginalFile', OriginalFile, -1, (), True, False, _M_omero.model._t_IObject, (), (
        ('_version', (), _M_omero._t_RInt, False, 0),
        ('_pixelsFileMapsSeq', (), _M_omero.model._t_OriginalFilePixelsFileMapsSeq, False, 0),
        ('_pixelsFileMapsLoaded', (), IcePy._t_bool, False, 0),
        ('_pixelsFileMapsCountPerOwner', (), _M_omero.sys._t_CountMap, False, 0),
        ('_path', (), _M_omero._t_RString, False, 0),
        ('_repo', (), _M_omero._t_RString, False, 0),
        ('_size', (), _M_omero._t_RLong, False, 0),
        ('_atime', (), _M_omero._t_RTime, False, 0),
        ('_mtime', (), _M_omero._t_RTime, False, 0),
        ('_ctime', (), _M_omero._t_RTime, False, 0),
        ('_hasher', (), _M_omero.model._t_ChecksumAlgorithm, False, 0),
        ('_hash', (), _M_omero._t_RString, False, 0),
        ('_mimetype', (), _M_omero._t_RString, False, 0),
        ('_filesetEntriesSeq', (), _M_omero.model._t_OriginalFileFilesetEntriesSeq, False, 0),
        ('_filesetEntriesLoaded', (), IcePy._t_bool, False, 0),
        ('_annotationLinksSeq', (), _M_omero.model._t_OriginalFileAnnotationLinksSeq, False, 0),
        ('_annotationLinksLoaded', (), IcePy._t_bool, False, 0),
        ('_annotationLinksCountPerOwner', (), _M_omero.sys._t_CountMap, False, 0),
        ('_name', (), _M_omero._t_RString, False, 0)
    ))
    OriginalFile._ice_type = _M_omero.model._t_OriginalFile

    OriginalFile._op_getVersion = IcePy.Operation('getVersion', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RInt, False, 0), ())
    OriginalFile._op_setVersion = IcePy.Operation('setVersion', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RInt, False, 0),), (), None, ())
    OriginalFile._op_unloadPixelsFileMaps = IcePy.Operation('unloadPixelsFileMaps', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), None, ())
    OriginalFile._op_sizeOfPixelsFileMaps = IcePy.Operation('sizeOfPixelsFileMaps', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), IcePy._t_int, False, 0), ())
    OriginalFile._op_copyPixelsFileMaps = IcePy.Operation('copyPixelsFileMaps', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_OriginalFilePixelsFileMapsSeq, False, 0), ())
    OriginalFile._op_addPixelsOriginalFileMap = IcePy.Operation('addPixelsOriginalFileMap', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_PixelsOriginalFileMap, False, 0),), (), None, ())
    OriginalFile._op_addAllPixelsOriginalFileMapSet = IcePy.Operation('addAllPixelsOriginalFileMapSet', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_OriginalFilePixelsFileMapsSeq, False, 0),), (), None, ())
    OriginalFile._op_removePixelsOriginalFileMap = IcePy.Operation('removePixelsOriginalFileMap', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_PixelsOriginalFileMap, False, 0),), (), None, ())
    OriginalFile._op_removeAllPixelsOriginalFileMapSet = IcePy.Operation('removeAllPixelsOriginalFileMapSet', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_OriginalFilePixelsFileMapsSeq, False, 0),), (), None, ())
    OriginalFile._op_clearPixelsFileMaps = IcePy.Operation('clearPixelsFileMaps', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), None, ())
    OriginalFile._op_reloadPixelsFileMaps = IcePy.Operation('reloadPixelsFileMaps', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_OriginalFile, False, 0),), (), None, ())
    OriginalFile._op_getPixelsFileMapsCountPerOwner = IcePy.Operation('getPixelsFileMapsCountPerOwner', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.sys._t_CountMap, False, 0), ())
    OriginalFile._op_linkPixels = IcePy.Operation('linkPixels', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Pixels, False, 0),), (), ((), _M_omero.model._t_PixelsOriginalFileMap, False, 0), ())
    OriginalFile._op_addPixelsOriginalFileMapToBoth = IcePy.Operation('addPixelsOriginalFileMapToBoth', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_PixelsOriginalFileMap, False, 0), ((), IcePy._t_bool, False, 0)), (), None, ())
    OriginalFile._op_findPixelsOriginalFileMap = IcePy.Operation('findPixelsOriginalFileMap', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Pixels, False, 0),), (), ((), _M_omero.model._t_OriginalFilePixelsFileMapsSeq, False, 0), ())
    OriginalFile._op_unlinkPixels = IcePy.Operation('unlinkPixels', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Pixels, False, 0),), (), None, ())
    OriginalFile._op_removePixelsOriginalFileMapFromBoth = IcePy.Operation('removePixelsOriginalFileMapFromBoth', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_PixelsOriginalFileMap, False, 0), ((), IcePy._t_bool, False, 0)), (), None, ())
    OriginalFile._op_linkedPixelsList = IcePy.Operation('linkedPixelsList', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_OriginalFileLinkedPixelsSeq, False, 0), ())
    OriginalFile._op_getPath = IcePy.Operation('getPath', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RString, False, 0), ())
    OriginalFile._op_setPath = IcePy.Operation('setPath', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RString, False, 0),), (), None, ())
    OriginalFile._op_getRepo = IcePy.Operation('getRepo', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RString, False, 0), ())
    OriginalFile._op_setRepo = IcePy.Operation('setRepo', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RString, False, 0),), (), None, ())
    OriginalFile._op_getSize = IcePy.Operation('getSize', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RLong, False, 0), ())
    OriginalFile._op_setSize = IcePy.Operation('setSize', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RLong, False, 0),), (), None, ())
    OriginalFile._op_getAtime = IcePy.Operation('getAtime', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RTime, False, 0), ())
    OriginalFile._op_setAtime = IcePy.Operation('setAtime', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RTime, False, 0),), (), None, ())
    OriginalFile._op_getMtime = IcePy.Operation('getMtime', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RTime, False, 0), ())
    OriginalFile._op_setMtime = IcePy.Operation('setMtime', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RTime, False, 0),), (), None, ())
    OriginalFile._op_getCtime = IcePy.Operation('getCtime', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RTime, False, 0), ())
    OriginalFile._op_setCtime = IcePy.Operation('setCtime', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RTime, False, 0),), (), None, ())
    OriginalFile._op_getHasher = IcePy.Operation('getHasher', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_ChecksumAlgorithm, False, 0), ())
    OriginalFile._op_setHasher = IcePy.Operation('setHasher', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_ChecksumAlgorithm, False, 0),), (), None, ())
    OriginalFile._op_getHash = IcePy.Operation('getHash', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RString, False, 0), ())
    OriginalFile._op_setHash = IcePy.Operation('setHash', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RString, False, 0),), (), None, ())
    OriginalFile._op_getMimetype = IcePy.Operation('getMimetype', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RString, False, 0), ())
    OriginalFile._op_setMimetype = IcePy.Operation('setMimetype', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RString, False, 0),), (), None, ())
    OriginalFile._op_unloadFilesetEntries = IcePy.Operation('unloadFilesetEntries', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), None, ())
    OriginalFile._op_sizeOfFilesetEntries = IcePy.Operation('sizeOfFilesetEntries', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), IcePy._t_int, False, 0), ())
    OriginalFile._op_copyFilesetEntries = IcePy.Operation('copyFilesetEntries', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_OriginalFileFilesetEntriesSeq, False, 0), ())
    OriginalFile._op_addFilesetEntry = IcePy.Operation('addFilesetEntry', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_FilesetEntry, False, 0),), (), None, ())
    OriginalFile._op_addAllFilesetEntrySet = IcePy.Operation('addAllFilesetEntrySet', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_OriginalFileFilesetEntriesSeq, False, 0),), (), None, ())
    OriginalFile._op_removeFilesetEntry = IcePy.Operation('removeFilesetEntry', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_FilesetEntry, False, 0),), (), None, ())
    OriginalFile._op_removeAllFilesetEntrySet = IcePy.Operation('removeAllFilesetEntrySet', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_OriginalFileFilesetEntriesSeq, False, 0),), (), None, ())
    OriginalFile._op_clearFilesetEntries = IcePy.Operation('clearFilesetEntries', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), None, ())
    OriginalFile._op_reloadFilesetEntries = IcePy.Operation('reloadFilesetEntries', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_OriginalFile, False, 0),), (), None, ())
    OriginalFile._op_unloadAnnotationLinks = IcePy.Operation('unloadAnnotationLinks', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), None, ())
    OriginalFile._op_sizeOfAnnotationLinks = IcePy.Operation('sizeOfAnnotationLinks', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), IcePy._t_int, False, 0), ())
    OriginalFile._op_copyAnnotationLinks = IcePy.Operation('copyAnnotationLinks', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_OriginalFileAnnotationLinksSeq, False, 0), ())
    OriginalFile._op_addOriginalFileAnnotationLink = IcePy.Operation('addOriginalFileAnnotationLink', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_OriginalFileAnnotationLink, False, 0),), (), None, ())
    OriginalFile._op_addAllOriginalFileAnnotationLinkSet = IcePy.Operation('addAllOriginalFileAnnotationLinkSet', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_OriginalFileAnnotationLinksSeq, False, 0),), (), None, ())
    OriginalFile._op_removeOriginalFileAnnotationLink = IcePy.Operation('removeOriginalFileAnnotationLink', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_OriginalFileAnnotationLink, False, 0),), (), None, ())
    OriginalFile._op_removeAllOriginalFileAnnotationLinkSet = IcePy.Operation('removeAllOriginalFileAnnotationLinkSet', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_OriginalFileAnnotationLinksSeq, False, 0),), (), None, ())
    OriginalFile._op_clearAnnotationLinks = IcePy.Operation('clearAnnotationLinks', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), None, ())
    OriginalFile._op_reloadAnnotationLinks = IcePy.Operation('reloadAnnotationLinks', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_OriginalFile, False, 0),), (), None, ())
    OriginalFile._op_getAnnotationLinksCountPerOwner = IcePy.Operation('getAnnotationLinksCountPerOwner', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.sys._t_CountMap, False, 0), ())
    OriginalFile._op_linkAnnotation = IcePy.Operation('linkAnnotation', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Annotation, False, 0),), (), ((), _M_omero.model._t_OriginalFileAnnotationLink, False, 0), ())
    OriginalFile._op_addOriginalFileAnnotationLinkToBoth = IcePy.Operation('addOriginalFileAnnotationLinkToBoth', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_OriginalFileAnnotationLink, False, 0), ((), IcePy._t_bool, False, 0)), (), None, ())
    OriginalFile._op_findOriginalFileAnnotationLink = IcePy.Operation('findOriginalFileAnnotationLink', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Annotation, False, 0),), (), ((), _M_omero.model._t_OriginalFileAnnotationLinksSeq, False, 0), ())
    OriginalFile._op_unlinkAnnotation = IcePy.Operation('unlinkAnnotation', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Annotation, False, 0),), (), None, ())
    OriginalFile._op_removeOriginalFileAnnotationLinkFromBoth = IcePy.Operation('removeOriginalFileAnnotationLinkFromBoth', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_OriginalFileAnnotationLink, False, 0), ((), IcePy._t_bool, False, 0)), (), None, ())
    OriginalFile._op_linkedAnnotationList = IcePy.Operation('linkedAnnotationList', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_OriginalFileLinkedAnnotationSeq, False, 0), ())
    OriginalFile._op_getName = IcePy.Operation('getName', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RString, False, 0), ())
    OriginalFile._op_setName = IcePy.Operation('setName', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RString, False, 0),), (), None, ())

    _M_omero.model.OriginalFile = OriginalFile
    del OriginalFile

    _M_omero.model.OriginalFilePrx = OriginalFilePrx
    del OriginalFilePrx

# End of module omero.model

__name__ = 'omero'

# End of module omero



#!/usr/bin/env python
# -*- coding: utf-8 -*-

#
# Copyright 2008, 2016 Glencoe Software, Inc.  All Rights Reserved.
# Use is subject to license terms supplied in LICENSE.txt
# Josh Moore, josh at glencoesoftware.com

"""
OMERO Grid node controller

This is a python wrapper around icegridnode.
"""
from __future__ import division
from __future__ import print_function

from builtins import str
from past.utils import old_div
from omero.cli import BaseControl, CLI, NonZeroReturnCode
from omero.util import tail_lines
import os
import sys
import signal
import platform
from omero_ext.path import path

from omero.install.windows_warning import windows_warning, WINDOWS_WARNING

HELP = """Control icegridnode.

           start       -- Start the node via icegridnode. With sync doesn't \
return until reachable.
           stop        -- Stop the node via icegridadmin. With sync doesn't \
return until stopped.
           status      -- Prints a status message. Return code is non-zero if\
 there is a problem.
           restart     -- Calls "sync start" then "stop" ("sync stop" if sync\
 is specified)

        node-name cannot be "start", "stop", "restart", "status", or "sync".
"""

if platform.system() == 'Windows':
    HELP += ("\n\n%s" % WINDOWS_WARNING)


class NodeControl(BaseControl):

    def _configure(self, parser):
        parser.add_argument(
            "name", nargs="?",
            help="Optional name of this node.", default=self._node())
        parser.add_argument(
            "sync", nargs="?", choices=("sync",),
            help="Whether or not to call wait on results")
        parser.add_argument(
            "command", nargs="+",
            choices=("start", "stop", "status", "restart"))
        parser.add_argument(
            "--foreground", action="store_true",
            help="Start in foreground mode (no daemon/service)")
        parser.set_defaults(func=self.__call__)

    def __call__(self, args):
        self._node(args.name)  # Set environment value
        for act in args.command:
            c = getattr(self, act)
            c(args)

    def _handleNZRC(self, nzrc):
        """
        Set the return value from nzrc on the context, and print
        out the last two lines of any error messages if present.
        """
        props = self._properties()
        self.ctx.rv = nzrc.rv
        myoutput = old_div(self.dir, path(props["Ice.StdErr"]))
        if not myoutput.exists():
            pass
        else:
            print("from %s:" % str(myoutput))
            print(tail_lines(str(myoutput), 2))

    @windows_warning
    def start(self, args):

        self.ctx.invoke(["admin", "rewrite"])
        self._initDir()

        try:
            command = ["icegridnode", self._icecfg()]
            if self._isWindows():
                self.ctx.die(128, "Not implemented")
                # The following code clearly hasn't been tested.
                # TODO: Fix this or remove it completely
                command = command + ["--install", "OMERO."+args.node]
                self.ctx.call(command)
                self.ctx.call(["icegridnode", "--start", "OMERO."+args.node])
            else:
                if args.foreground:
                    command = command + ["--nochdir"]
                else:
                    command = command + ["--daemon", "--pidfile",
                                         str(self._pid()), "--nochdir"]
                self.ctx.call(command)
        except OSError as o:
                msg = """%s\nPossibly an error finding "icegridnode". Try \
"icegridnode -h" from the command line.""" % o
                raise Exception(msg)
        except NonZeroReturnCode as nzrc:
                self._handleNZRC(nzrc)

    def status(self, args):
        self.ctx.invoke(["admin", "status", args.name])

    @windows_warning
    def stop(self, args):
        if self._isWindows():
            try:
                command = ["icegridnode", "--stop", "OMERO."+args.name]
                self.ctx.call(command)
                command = ["icegridnode", "--uninstall", "OMERO."+args.name]
                self.ctx.call(command)
            except NonZeroReturnCode as nzrc:
                self._handleNZRC(nzrc)
        else:
                pid = open(self._pid(), "r").readline()
                os.kill(int(pid), signal.SIGTERM)
                # command = ["icegridadmin"] + [self._intcfg()] + ["-c", "node
                # shutdown %s" % args.name]
                # self.ctx.call(command)

    @windows_warning
    def kill(self, args):
        pid = open(self._pid(), "r").readline()
        os.kill(int(pid), signal.SIGKILL)

try:
    register("node", NodeControl, HELP)
except NameError:
    if __name__ == "__main__":
        cli = CLI()
        cli.loadplugins()
        cli.invoke(sys.argv[1:])
